@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 void loadMusic(char *);
@@ -26,8 +26,8 @@ void stopMusic(void);
 void pauseMusic(int);
 void fadeOutMusic(int);
 void fadeInMusic(int);
-void setMusicVolume(void);
 void resumeMusic(void);
 void fadeBossMusic(void);
 void loadGameOverMusic(void);
 void playLoadedMusic(void);
+void updateMusicVolume(void);
