@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,29 +14,29 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../game.h"
 #include "../audio/music.h"
 #include "../collisions.h"
-#include "../item/key_items.h"
-#include "../item/item.h"
+#include "../credits.h"
+#include "../custom_actions.h"
+#include "../entity.h"
+#include "../event/script.h"
+#include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
 #include "../graphics/decoration.h"
 #include "../hud.h"
+#include "../item/item.h"
+#include "../item/key_items.h"
 #include "../player.h"
-#include "../geometry.h"
 #include "../system/error.h"
-#include "../event/script.h"
-#include "../credits.h"
+#include "../system/properties.h"
+#include "../system/random.h"
 
 extern Entity *self, player;
 
@@ -279,6 +279,8 @@ static void lookForPlayer()
 				playSoundToMap("sound/boss/armour_boss/growl.ogg", BOSS_CHANNEL, self->x, self->y, 0);
 
 				self->action = &chargeAttackStart;
+				
+				self->startX = 3600;
 			}
 		}
 
@@ -865,6 +867,8 @@ static void dieFinish()
 
 	if (self->thinkTime <= 0)
 	{
+		clearContinuePoint();
+		
 		increaseKillCount();
 
 		freeBossHealthBar();
