@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,30 +14,29 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../enemy/rock.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../collisions.h"
-#include "../map.h"
-#include "../game.h"
 #include "../audio/music.h"
-#include "../audio/audio.h"
-#include "../item/key_items.h"
+#include "../collisions.h"
+#include "../credits.h"
+#include "../custom_actions.h"
+#include "../enemy/rock.h"
+#include "../entity.h"
+#include "../game.h"
+#include "../graphics/animation.h"
 #include "../hud.h"
 #include "../inventory.h"
-#include "../world/target.h"
+#include "../item/key_items.h"
+#include "../map.h"
 #include "../player.h"
 #include "../system/error.h"
-#include "../credits.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 
@@ -122,7 +121,7 @@ Entity *addBlobBoss(int x, int y, char *name)
 	}
 
 	e->draw = &drawLoopingAnimationToMap;
-	
+
 	e->creditsAction = &bossMoveToMiddle;
 
 	e->type = ENEMY;
@@ -227,13 +226,7 @@ static void doIntro()
 static void reform()
 {
 	checkToMap(self);
-	/*
-	if (outOfBounds(self) == TRUE)
-	{
-		self->x = self->targetX;
-		self->y = self->targetY;
-	}
-	*/
+
 	if (self->thinkTime > 0)
 	{
 		self->thinkTime--;
@@ -819,7 +812,7 @@ static void bounceAroundInit()
 static void bounceAround()
 {
 	long onGround = self->flags & ON_GROUND;
-	
+
 	checkToMap(self);
 
 	if (self->flags & ON_GROUND)
@@ -828,7 +821,7 @@ static void bounceAround()
 		{
 			playSoundToMap("sound/boss/blob_boss/bounce.ogg", BOSS_CHANNEL, self->x, self->y, 0);
 		}
-		
+
 		self->maxThinkTime--;
 
 		if (self->maxThinkTime > 0)
@@ -1353,12 +1346,6 @@ static void partAttack()
 {
 	long onGround = (self->flags & ON_GROUND);
 
-	if (outOfBounds(self) == TRUE)
-	{
-		self->x = self->targetX;
-		self->y = self->targetY;
-	}
-
 	checkToMap(self);
 
 	/* Bounce towards player */
@@ -1439,6 +1426,8 @@ static void stickToPlayerAndDrain()
 {
 	Entity *temp;
 
+	setInfoBoxMessage(0, 255, 255, 255, _("Quickly turn left and right to shake off the pieces!"));
+
 	setCustomAction(&player, &slowDown, 3, 0, 0);
 
 	self->x = player.x + (player.w - self->w) / 2 + self->startX;
