@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,35 +14,34 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../enemy/rock.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../collisions.h"
-#include "../projectile.h"
-#include "../game.h"
 #include "../audio/music.h"
-#include "../audio/audio.h"
-#include "../graphics/gib.h"
+#include "../collisions.h"
+#include "../credits.h"
+#include "../custom_actions.h"
+#include "../enemy/rock.h"
+#include "../entity.h"
+#include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
 #include "../graphics/decoration.h"
-#include "../item/key_items.h"
+#include "../graphics/gib.h"
 #include "../hud.h"
 #include "../inventory.h"
-#include "../player.h"
-#include "../system/error.h"
-#include "../item/item.h"
 #include "../item/bomb.h"
-#include "../geometry.h"
+#include "../item/item.h"
+#include "../item/key_items.h"
+#include "../player.h"
+#include "../projectile.h"
+#include "../system/error.h"
+#include "../system/properties.h"
+#include "../system/random.h"
 #include "../world/explosion.h"
-#include "../credits.h"
 
 extern Entity *self, player;
 
@@ -108,7 +107,7 @@ Entity *addBorerBoss(int x, int y, char *name)
 	e->touch = NULL;
 
 	e->draw = &drawLoopingAnimationToMap;
-	
+
 	e->creditsAction = &creditsMove;
 
 	e->type = ENEMY;
@@ -176,7 +175,7 @@ static void addTentacles()
 		e->action = &tentacleWait;
 
 		e->draw = &drawTentacle;
-		
+
 		e->creditsAction = &tentacleWait;
 
 		e->type = ENEMY;
@@ -208,7 +207,7 @@ static void addMouth()
 	e->action = &mouthWait;
 
 	e->draw = &drawLoopingAnimationToMap;
-	
+
 	e->creditsAction = &mouthWait;
 
 	e->type = ENEMY;
@@ -593,25 +592,7 @@ static void bombMove()
 
 static void rockBlock(Entity *other)
 {
-	Entity *e;
-
-	e = addSmallRock(self->x, self->y, "common/small_rock");
-
-	e->x += (self->w - e->w) / 2;
-	e->y += (self->h - e->h) / 2;
-
-	e->dirX = 3;
-	e->dirY = -4;
-
-	e = addSmallRock(self->x, self->y, "common/small_rock");
-
-	e->x += (self->w - e->w) / 2;
-	e->y += (self->h - e->h) / 2;
-
-	e->dirX = 3;
-	e->dirY = -8;
-
-	self->inUse = FALSE;
+	self->dirX = 0;
 }
 
 static void takeDamage(Entity *other, int damage)
@@ -724,7 +705,7 @@ static void tentacleWait()
 			self->action = &tentacleAttackInit;
 		}
 	}
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -1205,7 +1186,7 @@ static void redTentacleAttackFinish()
 
 			self->health = 30;
 
-			stopSound(self->target->targetX);
+			stopSound(self->target->endX);
 
 			self->thinkTime = 30;
 
@@ -1476,12 +1457,12 @@ static void leave()
 static void creditsMove()
 {
 	int x = self->targetX;
-	
+
 	addMouth();
-	
+
 	addTentacles();
-	
+
 	self->creditsAction = &bossMoveToMiddle;
-	
+
 	self->targetX = x;
 }
