@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,36 +14,35 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../collisions.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
 #include "../audio/music.h"
-#include "../custom_actions.h"
-#include "../graphics/decoration.h"
-#include "../game.h"
-#include "../hud.h"
-#include "../map.h"
-#include "../projectile.h"
-#include "../item/key_items.h"
-#include "../item/item.h"
-#include "../player.h"
-#include "../inventory.h"
-#include "../system/error.h"
-#include "../world/target.h"
-#include "../geometry.h"
-#include "../enemy/egg.h"
-#include "../event/trigger.h"
-#include "../event/global_trigger.h"
-#include "../geometry.h"
+#include "../collisions.h"
 #include "../credits.h"
+#include "../custom_actions.h"
+#include "../enemy/egg.h"
+#include "../entity.h"
+#include "../event/global_trigger.h"
+#include "../event/trigger.h"
+#include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
+#include "../graphics/decoration.h"
+#include "../hud.h"
+#include "../inventory.h"
+#include "../item/item.h"
+#include "../item/key_items.h"
+#include "../map.h"
+#include "../player.h"
+#include "../projectile.h"
+#include "../system/error.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 
@@ -130,7 +129,7 @@ Entity *addCaveBoss(int x, int y, char *name)
 	e->draw = &drawCaveBoss;
 
 	e->die = &die;
-	
+
 	e->creditsAction = &bossMoveToMiddle;
 
 	e->type = ENEMY;
@@ -181,8 +180,6 @@ static void doIntro()
 
 		self->action = &attackFinished;
 
-		checkToMap(self);
-
 		self->startX = 0;
 
 		self->endX = 0;
@@ -1984,7 +1981,7 @@ static void acidStreamMoveToTop()
 
 		self->face = prand() % 2 == 0 ? LEFT : RIGHT;
 
-		self->targetX = self->face == LEFT ? getMapStartX() : getMapStartX() + SCREEN_WIDTH - self->w - 1;
+		self->targetX = self->face == LEFT ? getMapStartX() : getMapStartX() + SCREEN_WIDTH - self->w;
 
 		self->dirX = self->face == LEFT ? -self->speed : self->speed;
 	}
