@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,35 +14,35 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../collisions.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../game.h"
 #include "../audio/music.h"
-#include "../player.h"
-#include "../hud.h"
-#include "../map.h"
+#include "../collisions.h"
+#include "../credits.h"
+#include "../custom_actions.h"
 #include "../dialog.h"
-#include "../system/error.h"
-#include "../world/target.h"
-#include "../item/item.h"
+#include "../entity.h"
+#include "../event/script.h"
+#include "../game.h"
+#include "../graphics/animation.h"
+#include "../hud.h"
+#include "../inventory.h"
+#include "../item/bomb.h"
 #include "../item/exploding_gazer_eye.h"
 #include "../item/exploding_gazer_eye_dud.h"
 #include "../item/glass_cage.h"
-#include "../item/bomb.h"
+#include "../item/item.h"
+#include "../map.h"
+#include "../player.h"
 #include "../projectile.h"
-#include "../inventory.h"
-#include "../event/script.h"
-#include "../credits.h"
+#include "../system/error.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 
@@ -345,7 +345,7 @@ static void fireArrow()
 {
 	Entity *e;
 
-	e = addProjectile(self->startX == 1 ? "weapon/flaming_arrow" : "weapon/normal_arrow", self, self->x + (self->face == RIGHT ? 0 : self->w), self->y + 27, self->face == RIGHT ? 12 : -12, 0);
+	e = addProjectile(self->startX == 1 ? "weapon/flaming_arrow" : "weapon/normal_arrow", self, self->x + (self->face == RIGHT ? 0 : self->w), self->y + self->offsetY, self->face == RIGHT ? 12 : -12, 0);
 
 	e->damage = 1;
 
