@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,36 +14,36 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../map.h"
 #include "../audio/music.h"
-#include "../item/item.h"
+#include "../boss/grimlore_summon_spell.h"
 #include "../collisions.h"
+#include "../credits.h"
 #include "../custom_actions.h"
-#include "../hud.h"
-#include "../game.h"
-#include "../inventory.h"
-#include "../player.h"
-#include "../graphics/graphics.h"
-#include "../graphics/decoration.h"
-#include "../world/target.h"
+#include "../enemy/magic_missile.h"
 #include "../enemy/rock.h"
+#include "../entity.h"
+#include "../game.h"
+#include "../graphics/animation.h"
+#include "../graphics/decoration.h"
+#include "../graphics/graphics.h"
+#include "../hud.h"
+#include "../inventory.h"
 #include "../item/grimlore_artifact.h"
+#include "../item/item.h"
+#include "../map.h"
+#include "../player.h"
 #include "../projectile.h"
 #include "../system/error.h"
-#include "../enemy/magic_missile.h"
-#include "../boss/grimlore_summon_spell.h"
+#include "../system/properties.h"
+#include "../system/random.h"
 #include "../world/explosion.h"
-#include "../credits.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 extern Game game;
@@ -151,7 +151,7 @@ Entity *addGrimlore(int x, int y, char *name)
 
 	e->draw = &drawLoopingAnimationToMap;
 	e->takeDamage = &takeDamage;
-	
+
 	e->creditsAction = &creditsMove;
 
 	e->type = ENEMY;
@@ -406,7 +406,7 @@ static void addArmour()
 	e->draw = &drawLoopingAnimationToMap;
 	e->die = &armourDie;
 	e->touch = &entityTouch;
-	
+
 	e->creditsAction = &armourWait;
 
 	e->type = ENEMY;
@@ -447,7 +447,7 @@ static void armourWait()
 	{
 		self->die();
 	}
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -476,7 +476,7 @@ static void addShield()
 	e->takeDamage = &shieldTakeDamage;
 	e->die = &shieldDie;
 	e->touch = &entityTouch;
-	
+
 	e->creditsAction = &shieldWait;
 
 	e->type = ENEMY;
@@ -527,7 +527,7 @@ static void shieldWait()
 	}
 
 	self->y = self->head->y + self->offsetY;
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -557,7 +557,7 @@ static void addSword()
 	e->takeDamage = &swordTakeDamage;
 
 	e->draw = &drawLoopingAnimationToMap;
-	
+
 	e->creditsAction = &swordWait;
 
 	e->type = ENEMY;
@@ -605,7 +605,7 @@ static void swordWait()
 	}
 
 	self->y = self->head->y + self->offsetY;
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -1582,13 +1582,13 @@ static void shieldBiteReactToBlock(Entity *other)
 {
 	self->endX = self->face == LEFT ? self->x + 64 : self->x - 64;
 
-	self->dirX = self->face == LEFT ? 2 : -2;
-
 	self->action = &shieldBiteMoveBack;
 }
 
 static void shieldBiteMoveBack()
 {
+	self->dirX = self->face == LEFT ? 2 : -2;
+
 	if ((self->face == LEFT && (self->x >= self->endX || self->x >= self->startX)) || (self->face == RIGHT && (self->x <= self->endX || self->x <= self->startX)))
 	{
 		self->mental--;
@@ -2164,7 +2164,7 @@ static void beamAttack()
 			e->action = &beamMove;
 
 			e->draw = &beamDraw;
-			
+
 			e->targetX = playSoundToMap("sound/boss/grimlore/grimlore_beam.ogg", BOSS_CHANNEL, self->x, self->y, 0);
 
 			e->head = self;
@@ -2199,11 +2199,11 @@ static void beamMove()
 		self->thinkTime--;
 
 		self->flags |= NO_DRAW;
-		
+
 		if (self->targetX != -1)
 		{
 			stopSound(self->targetX);
-			
+
 			self->targetX = -1;
 		}
 
@@ -2336,7 +2336,7 @@ static void itemDestroyAttack()
 
 		fadeFromColour(255, 0, 0, 60);
 	}
-	
+
 	prev = first = NULL;
 
 	if (self->thinkTime <= 0)
@@ -2555,17 +2555,7 @@ static void itemDestroyerRetract()
 
 			e->damage = 1;
 
-			if (player.maxHealth > 5)
-			{
-				player.maxHealth--;
-
-				setInfoBoxMessage(90, 255, 255, 255, _("Your maximum health has decreased"));
-			}
-
-			if (player.health > player.maxHealth)
-			{
-				player.health = player.maxHealth;
-			}
+			setPlayerConfused(600);
 
 			self->head->maxThinkTime = 0;
 		}
@@ -2721,7 +2711,7 @@ static void itemDestroyerTakeDamage(Entity *other, int damage)
 
 static void destroyInventoryItem()
 {
-	int size, i;
+	int size, i, index;
 	Entity *e;
 	char itemName[MAX_VALUE_LENGTH];
 	char *items[] = {
@@ -2740,22 +2730,29 @@ static void destroyInventoryItem()
 		"item/tortoise_shell",
 		"item/summoner_staff",
 		"item/flaming_arrow_potion",
-		"item/resurrection_amulet"
+		"item/resurrection_amulet",
+		"item/keepsake",
+		"weapon/legendary_sword"
 	};
 
 	size = sizeof(items) / sizeof(char *);
 
-	i = prand() % size;
-
-	e = getInventoryItemByName(items[i]);
-
-	if (e != NULL)
+	for (i=0;i<size;i++)
 	{
-		STRNCPY(itemName, e->objectiveName, sizeof(itemName));
+		index = prand() % size;
 
-		removeInventoryItemByName(e->name);
+		e = getInventoryItemByName(items[index]);
 
-		setInfoBoxMessage(60, 255, 255, 255, _("Your %s has been destroyed"), itemName);
+		if (e != NULL)
+		{
+			STRNCPY(itemName, e->objectiveName, sizeof(itemName));
+
+			removeInventoryItemByName(e->name);
+
+			setInfoBoxMessage(60, 255, 255, 255, _("Your %s has been destroyed"), itemName);
+
+			return;
+		}
 	}
 }
 
@@ -3500,6 +3497,6 @@ static void creditsMove()
 	addSword();
 
 	addShield();
-	
+
 	self->creditsAction = &bossMoveToMiddle;
 }
