@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,31 +14,31 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../enemy/rock.h"
-#include "../collisions.h"
-#include "../geometry.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
 #include "../audio/music.h"
+#include "../collisions.h"
+#include "../credits.h"
 #include "../custom_actions.h"
-#include "../graphics/decoration.h"
+#include "../enemy/rock.h"
+#include "../entity.h"
 #include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
+#include "../graphics/decoration.h"
+#include "../graphics/gib.h"
 #include "../hud.h"
+#include "../item/item.h"
+#include "../item/key_items.h"
 #include "../map.h"
 #include "../player.h"
-#include "../item/key_items.h"
-#include "../item/item.h"
 #include "../system/error.h"
-#include "../graphics/gib.h"
-#include "../credits.h"
+#include "../system/properties.h"
+#include "../system/random.h"
 
 extern Entity *self, player;
 extern Game game;
@@ -123,7 +123,7 @@ Entity *addMataeus(int x, int y, char *name)
 	e->die = NULL;
 	e->takeDamage = NULL;
 	e->pain = &enemyPain;
-	
+
 	e->creditsAction = &creditsMove;
 
 	e->type = ENEMY;
@@ -555,16 +555,6 @@ static void knifeDie()
 
 static void specialKnifeBlock(Entity *other)
 {
-	self->flags &= ~FLY;
-
-	self->dirX = self->x < player.x ? -5 : 5;
-
-	self->dirY = -5;
-
-	self->thinkTime = 120;
-
-	self->damage = 50;
-
 	self->action = &specialKnifeBlockWait;
 
 	self->activate = &throwItem;
@@ -572,16 +562,6 @@ static void specialKnifeBlock(Entity *other)
 
 static void knifeBlock(Entity *other)
 {
-	self->flags &= ~FLY;
-
-	self->dirX = self->x < player.x ? -5 : 5;
-
-	self->dirY = -5;
-
-	self->thinkTime = 120;
-
-	self->damage = 50;
-
 	self->action = &knifeBlockWait;
 
 	self->activate = &throwItem;
@@ -589,6 +569,19 @@ static void knifeBlock(Entity *other)
 
 static void specialKnifeBlockWait(void)
 {
+	if (self->flags & FLY)
+	{
+		self->flags &= ~FLY;
+
+		self->dirX = self->x < player.x ? -5 : 5;
+
+		self->dirY = -5;
+
+		self->thinkTime = 120;
+
+		self->damage = 50;
+	}
+
 	checkToMap(self);
 
 	if (self->flags & ON_GROUND)
@@ -607,6 +600,19 @@ static void specialKnifeBlockWait(void)
 
 static void knifeBlockWait()
 {
+	if (self->flags & FLY)
+	{
+		self->flags &= ~FLY;
+
+		self->dirX = self->x < player.x ? -5 : 5;
+
+		self->dirY = -5;
+
+		self->thinkTime = 120;
+
+		self->damage = 50;
+	}
+
 	checkToMap(self);
 
 	if (self->flags & ON_GROUND)
@@ -1189,6 +1195,8 @@ static void anchorDie()
 
 	e = self;
 
+	playSoundToMap("sound/enemy/centurion/centurion_die.ogg", -1, self->x, self->y, 0);
+
 	self = self->target;
 
 	while (self != NULL)
@@ -1418,7 +1426,7 @@ static void riftRise()
 	if (self->y <= self->startY)
 	{
 		stopSound(self->health);
-		
+
 		self->health = playSoundToMap("sound/item/rift.ogg", -1, self->x, self->y, -1);
 
 		self->y = self->startY;
@@ -1462,8 +1470,6 @@ static void riftAttract()
 
 	if (self->thinkTime <= 0)
 	{
-		self->health = -1;
-
 		self->touch = NULL;
 
 		setEntityAnimation(self, "STAND");
@@ -1484,7 +1490,7 @@ static void riftAttract()
 static void riftSink()
 {
 	stopSound(self->health);
-	
+
 	self->health = playSoundToMap("sound/boss/ant_lion/earthquake.ogg", BOSS_CHANNEL, self->x, self->y, -1);
 
 	self->y += 0.5;
@@ -1703,7 +1709,7 @@ static void addRiftEnergy(int x, int y)
 	Entity *e;
 
 	e = addBasicDecoration(x, y, "decoration/rift_energy");
-	
+
 	if (e != NULL)
 	{
 		e->x += prand() % 128 * (prand() % 2 == 0 ? -1 : 1);
@@ -1968,6 +1974,6 @@ static void horizontalKnifeWait()
 static void creditsMove()
 {
 	setEntityAnimation(self, "STAND");
-	
+
 	self->creditsAction = &bossMoveToMiddle;
 }
