@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,32 +14,31 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../collisions.h"
-#include "../projectile.h"
-#include "../map.h"
-#include "../game.h"
 #include "../audio/music.h"
-#include "../audio/audio.h"
-#include "../graphics/decoration.h"
-#include "../item/key_items.h"
-#include "../hud.h"
-#include "../world/target.h"
-#include "../player.h"
-#include "../system/error.h"
-#include "../geometry.h"
-#include "../event/script.h"
+#include "../collisions.h"
 #include "../credits.h"
+#include "../custom_actions.h"
+#include "../entity.h"
+#include "../event/script.h"
+#include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
+#include "../graphics/decoration.h"
+#include "../hud.h"
+#include "../item/key_items.h"
+#include "../map.h"
+#include "../player.h"
+#include "../projectile.h"
+#include "../system/error.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 
@@ -98,7 +97,7 @@ Entity *addPhoenix(int x, int y, char *name)
 	e->touch = NULL;
 
 	e->draw = &drawLoopingAnimationToMap;
-	
+
 	e->creditsAction = &bossMoveToMiddle;
 
 	e->type = ENEMY;
@@ -653,22 +652,65 @@ static void takeDamage(Entity *other, int damage)
 
 	if (self->mental > 0)
 	{
-		playSoundToMap("sound/common/dink.ogg", -1, self->x, self->y, 0);
-
-		if (other->reactToBlock != NULL)
+		if (other->element == FIRE)
 		{
-			temp = self;
+			self->health += damage;
 
-			self = other;
+			if (other->type == PROJECTILE)
+			{
+				other->target = self;
+			}
 
-			self->reactToBlock(temp);
+			setCustomAction(self, &flashWhite, 6, 0, 0);
 
-			self = temp;
+			/* Don't make an enemy invulnerable from a projectile hit, allows multiple hits */
+
+			if (other->type != PROJECTILE)
+			{
+				setCustomAction(self, &invulnerableNoFlash, HIT_INVULNERABLE_TIME, 0, 0);
+			}
+
+			if (self->pain != NULL)
+			{
+				self->pain();
+			}
+
+			if (prand() % 5 == 0)
+			{
+				setInfoBoxMessage(90, 255, 255, 255, _("The damage from this weapon is being absorbed..."));
+			}
+
+			if (other->type == PROJECTILE)
+			{
+				temp = self;
+
+				self = other;
+
+				self->die();
+
+				self = temp;
+			}
 		}
 
-		if (prand() % 10 == 0)
+		else
 		{
-			setInfoBoxMessage(60, 255, 255, 255, _("This weapon is not having any effect..."));
+			playSoundToMap("sound/common/dink.ogg", -1, self->x, self->y, 0);
+
+			if (other->reactToBlock != NULL)
+			{
+				temp = self;
+
+				self = other;
+
+				self->reactToBlock(temp);
+
+				self = temp;
+			}
+
+			if (prand() % 10 == 0)
+			{
+				setInfoBoxMessage(60, 255, 255, 255, _("This weapon is not having any effect..."));
+			}
 		}
 
 		setCustomAction(self, &invulnerableNoFlash, HIT_INVULNERABLE_TIME, 0, 0);
@@ -692,21 +734,15 @@ static void takeDamage(Entity *other, int damage)
 
 		if (damage != 0)
 		{
-			self->health -= damage;
-
-			if (other->type == PROJECTILE)
+			if (other->element == FIRE)
 			{
-				temp = self;
+				self->health += damage;
 
-				self = other;
+				if (other->type == PROJECTILE)
+				{
+					other->target = self;
+				}
 
-				self->die();
-
-				self = temp;
-			}
-
-			if (self->health > 0)
-			{
 				setCustomAction(self, &flashWhite, 6, 0, 0);
 
 				/* Don't make an enemy invulnerable from a projectile hit, allows multiple hits */
@@ -720,21 +756,72 @@ static void takeDamage(Entity *other, int damage)
 				{
 					self->pain();
 				}
+
+				if (prand() % 5 == 0)
+				{
+					setInfoBoxMessage(90, 255, 255, 255, _("The damage from this weapon is being absorbed..."));
+				}
+
+				if (other->type == PROJECTILE)
+				{
+					temp = self;
+
+					self = other;
+
+					self->die();
+
+					self = temp;
+				}
+
+				self->thinkTime = 0;
 			}
 
 			else
 			{
-				self->takeDamage = NULL;
+				self->health -= damage;
 
-				self->thinkTime = 120;
+				if (other->type == PROJECTILE)
+				{
+					temp = self;
 
-				self->startX = self->x;
+					self = other;
 
-				self->damage = 0;
+					self->die();
 
-				self->endX = 0;
+					self = temp;
+				}
 
-				self->action = &die;
+				if (self->health > 0)
+				{
+					setCustomAction(self, &flashWhite, 6, 0, 0);
+
+					/* Don't make an enemy invulnerable from a projectile hit, allows multiple hits */
+
+					if (other->type != PROJECTILE)
+					{
+						setCustomAction(self, &invulnerableNoFlash, HIT_INVULNERABLE_TIME, 0, 0);
+					}
+
+					if (self->pain != NULL)
+					{
+						self->pain();
+					}
+				}
+
+				else
+				{
+					self->takeDamage = NULL;
+
+					self->thinkTime = 120;
+
+					self->startX = self->x;
+
+					self->damage = 0;
+
+					self->endX = 0;
+
+					self->action = &die;
+				}
 			}
 		}
 	}
@@ -968,6 +1055,7 @@ static void dieWait()
 		e->y = self->y + self->h - e->h;
 
 		e->action = &fireWait;
+
 		e->touch = &entityTouch;
 
 		e->draw = &drawLoopingAnimationToMap;
@@ -1097,6 +1185,7 @@ static void resurrectInit()
 			e->y = self->y + self->h - e->h;
 
 			e->action = &fireWait;
+
 			e->touch = &entityTouch;
 
 			e->draw = &drawLoopingAnimationToMap;
