@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,32 +14,31 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../collisions.h"
-#include "../projectile.h"
-#include "../map.h"
-#include "../game.h"
 #include "../audio/music.h"
-#include "../audio/audio.h"
+#include "../collisions.h"
+#include "../credits.h"
+#include "../custom_actions.h"
+#include "../entity.h"
+#include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
 #include "../graphics/decoration.h"
 #include "../hud.h"
 #include "../inventory.h"
-#include "../world/target.h"
-#include "../player.h"
-#include "../system/error.h"
 #include "../item/item.h"
-#include "../geometry.h"
-#include "../credits.h"
+#include "../map.h"
+#include "../player.h"
+#include "../projectile.h"
+#include "../system/error.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 
@@ -57,7 +56,6 @@ static void createArm(Entity *);
 static void clawWait(void);
 static void armPartWait(void);
 static void alignArmToClaw(void);
-static void hover(void);
 static void punchAttackInit(void);
 static void punchAttack(void);
 static void punchWait(void);
@@ -134,7 +132,7 @@ Entity *addSewerBoss(int x, int y, char *name)
 	e->action = &initialise;
 	e->touch = NULL;
 	e->fallout = &fallout;
-	
+
 	e->creditsAction = &creditsMove;
 
 	e->draw = &drawLoopingAnimationToMap;
@@ -242,12 +240,14 @@ static void entityWait()
 		{
 			if (self->health >= 300)
 			{
-				action = prand() % 3;
+				action = prand() % 5;
 
 				switch (action)
 				{
 					case 0:
 					case 1:
+					case 2:
+					case 3:
 						setEntityAnimation(self, self->element == SLIME ? "ATTACK_4" : "ATTACK_4_WATER");
 
 						self->mental = -10;
@@ -265,12 +265,13 @@ static void entityWait()
 
 			else if (self->health >= 200)
 			{
-				action = prand() % 5;
+				action = prand() % 7;
 
 				switch (action)
 				{
 					case 0:
 					case 1:
+					case 2:
 						setEntityAnimation(self, self->element == SLIME ? "ATTACK_4" : "ATTACK_4_WATER");
 
 						self->mental = -10;
@@ -278,8 +279,9 @@ static void entityWait()
 						self->action = &punchWait;
 					break;
 
-					case 2:
 					case 3:
+					case 4:
+					case 5:
 						setEntityAnimation(self, self->element == SLIME ? "ATTACK_4" : "ATTACK_4_WATER");
 
 						self->mental = -5;
@@ -297,12 +299,13 @@ static void entityWait()
 
 			else
 			{
-				action = prand() % 7;
+				action = prand() % 9;
 
 				switch (action)
 				{
 					case 0:
 					case 1:
+					case 2:
 						setEntityAnimation(self, self->element == SLIME ? "ATTACK_4" : "ATTACK_4_WATER");
 
 						self->mental = -10;
@@ -310,8 +313,9 @@ static void entityWait()
 						self->action = &punchWait;
 					break;
 
-					case 2:
 					case 3:
+					case 4:
+					case 5:
 						setEntityAnimation(self, self->element == SLIME ? "ATTACK_4" : "ATTACK_4_WATER");
 
 						self->mental = -5;
@@ -319,8 +323,9 @@ static void entityWait()
 						self->action = &punchWait;
 					break;
 
-					case 4:
-					case 5:
+					case 6:
+					case 7:
+					case 8:
 						self->dirY = self->speed;
 
 						self->action = &sinkAttackInit;
@@ -349,8 +354,6 @@ static void entityWait()
 	}
 
 	checkToMap(self);
-
-	hover();
 }
 
 static void punchWait()
@@ -520,7 +523,7 @@ static void addClaws()
 		e->die = &clawDie;
 		e->action = &clawWait;
 		e->takeDamage = &clawTakeDamage;
-		
+
 		e->creditsAction = &clawWait;
 
 		e->head = self;
@@ -573,7 +576,7 @@ static void createArm(Entity *top)
 		body[i]->draw = &drawLoopingAnimationToMap;
 		body[i]->touch = &entityTouch;
 		body[i]->die = &entityDieNoDrop;
-		
+
 		body[i]->creditsAction = &armPartWait;
 
 		body[i]->type = ENEMY;
@@ -813,7 +816,7 @@ static void clawWait()
 			self->inUse = FALSE;
 		}
 	}
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -887,7 +890,7 @@ static void clawSideAttackWait()
 
 static void clawSideAttack()
 {
-	if (atTarget())
+	if (atTarget() || self->dirX == 0)
 	{
 		self->targetX = self->startX;
 		self->targetY = self->y;
@@ -915,19 +918,11 @@ static void clawSideAttack()
 
 static void sideAttackReactToBlock(Entity *other)
 {
-	self->endX--;
+	self->dirX = 0;
 
-	self->targetX = self->startX;
-	self->targetY = self->y;
-
-	calculatePath(self->x, self->y, self->targetX, self->targetY, &self->dirX, &self->dirY);
-
-	self->dirX *= 6;
-	self->dirY *= 6;
-
-	self->action = &clawSideAttackWait;
-
-	self->thinkTime = 60;
+	self->targetX = self->x;
+	
+	self->x = (int)self->x;
 }
 
 static void clawSideAttackFinish()
@@ -966,6 +961,8 @@ static void punchAttackInit()
 			self->dirX *= 12;
 			self->dirY *= 12;
 
+			self->flags &= ~UNBLOCKABLE;
+
 			self->action = &punchAttack;
 
 			self->reactToBlock = &punchReactToBlock;
@@ -979,35 +976,11 @@ static void punchAttackInit()
 
 static void punchReactToBlock(Entity *other)
 {
-	self->endX--;
+	self->dirX = 0;
 
-	if (self->endX <= 0)
-	{
-		self->targetX = self->startX;
-		self->targetY = self->y;
-
-		calculatePath(self->x, self->y, self->targetX, self->targetY, &self->dirX, &self->dirY);
-
-		self->dirX *= 4;
-		self->dirY *= 4;
-
-		self->action = &punchAttackFinish;
-
-		self->thinkTime = 60;
-	}
-
-	else
-	{
-		self->targetX = self->face == LEFT ? self->startX - 64 : self->startX + 64;
-		self->targetY = self->startY;
-
-		calculatePath(self->x, self->y, self->targetX, self->targetY, &self->dirX, &self->dirY);
-
-		self->dirX *= 6;
-		self->dirY *= 6;
-
-		self->action = &punchAttackInit;
-	}
+	self->targetX = self->x;
+	
+	self->x = (int)self->x;
 }
 
 static void punchAttack()
@@ -1296,7 +1269,7 @@ static void armPartWait()
 
 		self->action = &armChangeToWater;
 	}
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -1343,20 +1316,6 @@ static void alignArmToClaw()
 	}
 }
 
-static void hover()
-{
-	return;
-
-	self->startX++;
-
-	if (self->startX >= 360)
-	{
-		self->startX = 0;
-	}
-
-	self->y = self->startY + sin(DEG_TO_RAD(self->startX)) * 16;
-}
-
 static void slimeAttackInit()
 {
 	Target *t = getTargetByName("SEWER_BOSS_SLIME_TARGET");
@@ -2274,7 +2233,7 @@ static void addSlimeDrips()
 
 		e->draw = &drawLoopingAnimationToMap;
 		e->action = &dripWait;
-		
+
 		e->creditsAction = &dripWait;
 
 		e->head = self;
@@ -2291,7 +2250,7 @@ static void dripWait()
 {
 	int frame;
 	float timer;
-	
+
 	self->face = self->head->face;
 
 	if (self->face == LEFT)
@@ -2316,12 +2275,12 @@ static void dripWait()
 	if (self->element == WATER && self->head->element != WATER)
 	{
 		self->element = SLIME;
-		
+
 		frame = self->currentFrame;
 		timer = self->frameTimer;
 
 		setEntityAnimationByID(self, self->mental);
-		
+
 		self->currentFrame = frame;
 		self->frameTimer = timer;
 	}
@@ -2405,11 +2364,11 @@ static void creditsMove()
 		addSlimeDrips();
 
 		addClaws();
-		
+
 		self->health = -1;
 	}
-	
+
 	bossMoveToMiddle();
-	
+
 	alignArmToClaw();
 }
