@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,31 +14,30 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
-#include "../system/properties.h"
-#include "../entity.h"
-#include "../system/random.h"
 #include "../audio/audio.h"
-#include "../custom_actions.h"
-#include "../map.h"
-#include "../game.h"
 #include "../audio/music.h"
 #include "../collisions.h"
-#include "../item/key_items.h"
-#include "../world/target.h"
-#include "../graphics/decoration.h"
-#include "../player.h"
-#include "../geometry.h"
-#include "../hud.h"
+#include "../credits.h"
+#include "../custom_actions.h"
+#include "../entity.h"
 #include "../game.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
+#include "../graphics/decoration.h"
+#include "../hud.h"
+#include "../item/key_items.h"
+#include "../map.h"
+#include "../player.h"
 #include "../projectile.h"
 #include "../system/error.h"
-#include "../credits.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
 
 extern Entity *self, player;
 
@@ -64,6 +63,7 @@ static void takeDamage(Entity *, int);
 static void shotAttackInit(void);
 static void shotAttackWindUp(void);
 static void shotAttack(void);
+static void specialShotMove(void);
 static void specialShotWait(void);
 static void specialShotBlock(Entity *);
 static void specialShotTouch(Entity *);
@@ -102,7 +102,7 @@ Entity *addSnakeBoss(int x, int y, char *name)
 	head->touch = &entityTouch;
 	head->die = &die;
 	head->takeDamage = &takeDamage;
-	
+
 	head->creditsAction = &creditsMove;
 
 	head->type = ENEMY;
@@ -127,7 +127,7 @@ static void bodyWait()
 	}
 
 	checkToMap(self);
-	
+
 	if (self->head->inUse == FALSE)
 	{
 		self->inUse = FALSE;
@@ -322,7 +322,7 @@ static void createBody()
 		body[i]->touch = &entityTouch;
 		body[i]->die = &entityDieNoDrop;
 		body[i]->takeDamage = &bodyTakeDamage;
-		
+
 		body[i]->creditsAction = &bodyWait;
 
 		body[i]->type = ENEMY;
@@ -399,6 +399,8 @@ static void biteAttackWindUp()
 		self->action = &biteAttack;
 
 		self->reactToBlock = &biteReactToBlock;
+		
+		self->dirX = (self->targetX < self->x ? -self->speed * 2 : self->speed * 2);
 	}
 
 	alignBodyToHead();
@@ -406,8 +408,6 @@ static void biteAttackWindUp()
 
 static void biteAttack()
 {
-	self->dirX = (self->targetX < self->x ? -self->speed * 2 : self->speed * 2);
-
 	checkToMap(self);
 
 	if (fabs(self->x - self->targetX) < self->speed)
@@ -484,10 +484,12 @@ static void shotAttack()
 	if (self->thinkTime <= 0)
 	{
 		playSoundToMap("sound/boss/snake_boss/snake_boss_shot.ogg", BOSS_CHANNEL, self->x, self->y, 0);
-		
+
 		if (prand() % 4 == 0 && self->startX == 0)
 		{
 			e = addProjectile("boss/snake_boss_special_shot", self, self->x + self->w / 2, self->y + self->h / 2, (self->face == RIGHT ? 7 : -7), 0);
+			
+			e->action = &specialShotMove;
 
 			e->reactToBlock = &specialShotBlock;
 
@@ -957,7 +959,7 @@ static void fallToGround()
 	if (self->thinkTime <= 0)
 	{
 		playSoundToMap("sound/boss/snake_boss/snake_boss_die.ogg", BOSS_CHANNEL, self->x, self->y, 0);
-		
+
 		self->flags &= ~FLY;
 
 		self->dirX = self->face == LEFT ? -8 : 8;
@@ -970,7 +972,7 @@ static void fallToGround()
 	if (self->flags & ON_GROUND)
 	{
 		playSoundToMap("sound/common/crash.ogg", BOSS_CHANNEL, self->x, self->y, 0);
-		
+
 		setEntityAnimation(self, "PAIN");
 
 		self->thinkTime = 180;
@@ -1038,27 +1040,37 @@ static void dieWait()
 	}
 }
 
+static void specialShotMove()
+{
+	if (!(self->flags & FLY))
+	{
+		self->dirX = (self->face == LEFT ? 5 : -5);
+
+		self->dirY = -5;
+
+		self->type = ENEMY;
+
+		self->target = self->parent;
+
+		self->parent = NULL;
+
+		self->action = &specialShotWait;
+
+		self->touch = NULL;
+
+		self->thinkTime = 300;
+
+		self->die = &entityDieNoDrop;
+	}
+	
+	checkToMap(self);
+}
+
 static void specialShotBlock(Entity *other)
 {
-	self->dirX = (self->dirX < 0 ? 5 : -5);
-
-	self->dirY = -5;
-
-	self->type = ENEMY;
-
-	self->target = self->parent;
-
-	self->parent = NULL;
-
+	self->dirX = 0;
+	
 	self->flags &= ~FLY;
-
-	self->action = &specialShotWait;
-
-	self->touch = NULL;
-
-	self->thinkTime = 300;
-
-	self->die = &entityDieNoDrop;
 }
 
 static void specialShotWait()
@@ -1106,25 +1118,11 @@ static void specialShotTouch(Entity *other)
 
 static void biteReactToBlock(Entity *other)
 {
-	self->maxThinkTime--;
+	self->dirX = 0;
 
-	if (self->maxThinkTime <= 0)
-	{
-		self->action = &attackFinished;
-	}
-
-	else
-	{
-		self->targetX = self->endX + (self->face == LEFT ? -32 : 32);
-		self->targetY = self->endY - 32;
-
-		calculatePath(self->x, self->y, self->targetX, self->targetY, &self->dirX, &self->dirY);
-
-		self->dirX *= 4;
-		self->dirY *= 4;
-
-		self->action = &biteAttackWindUp;
-	}
+	self->targetX = self->x;
+	
+	self->x = (int)self->x;
 }
 
 static void stunned()
@@ -1236,20 +1234,20 @@ static void creditsMove()
 	if (self->health != -1)
 	{
 		createBody();
-		
+
 		self->endY = self->y + 32;
-		
+
 		self->y -= 32;
-		
+
 		self->health = -1;
 	}
-	
+
 	bossMoveToMiddle();
-	
+
 	self->endX = self->x;
-	
+
 	alignBodyToHead();
-	
+
 	if (self->thinkTime <= 0)
 	{
 		self->creditsAction = &creditsMoveOffScreen;
@@ -1259,13 +1257,13 @@ static void creditsMove()
 static void creditsMoveOffScreen()
 {
 	self->x -= 20;
-	
+
 	if (self->x <= -self->w)
 	{
 		self->inUse = FALSE;
 	}
-	
+
 	self->endX = self->x;
-	
+
 	alignBodyToHead();
 }
