@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,15 +14,15 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
-#include "collisions.h"
-#include "map.h"
 #include "audio/audio.h"
+#include "collisions.h"
 #include "entity.h"
+#include "map.h"
 
 extern Entity *self;
 extern Entity player, playerShield, playerWeapon;
@@ -248,7 +248,7 @@ void doCollisions()
 								self = temp;
 							}
 						}
-						
+
 						if (e1->inUse == FALSE)
 						{
 							break;
@@ -366,7 +366,7 @@ Entity *checkEntityToEntity(Entity *e)
 Entity *isSpaceEmpty(Entity *e)
 {
 	EntityList *el, *entities;
-	
+
 	entities = getEntities();
 
 	if (player.inUse == TRUE && collision(e->x, e->y, e->w, e->h, player.x, player.y, player.w, player.h) == 1)
@@ -389,7 +389,7 @@ Entity *isSpaceEmpty(Entity *e)
 int isNearObstacle(Entity *e)
 {
 	EntityList *el, *entities;
-	
+
 	entities = getEntities();
 
 	for (el=entities->next;el!=NULL;el=el->next)
@@ -916,10 +916,10 @@ void checkToMap(Entity *e)
 	e->x += e->dirX;
 	e->y += e->dirY;
 
-	x1 = (e->type == PLAYER || (e->flags & LIMIT_TO_SCREEN)) ? getPlayerMinX() : getMinMapX();
-	x2 = (e->type == PLAYER || (e->flags & LIMIT_TO_SCREEN)) ? getPlayerMaxX() : getMaxMapX();
+	x1 = (e->type == PLAYER || (e->flags & LIMIT_TO_SCREEN)) ? getPlayerMinX() : getMapMinX();
+	x2 = (e->type == PLAYER || (e->flags & LIMIT_TO_SCREEN)) ? getPlayerMaxX() : getMapMaxX();
 
-	y1 = (e->flags & LIMIT_TO_SCREEN) ? getMapStartY() : getMinMapY() - 300;
+	y1 = (e->flags & LIMIT_TO_SCREEN) ? getMapStartY() : getMapMinY() - 300;
 
 	if (e->x < x1)
 	{
@@ -956,13 +956,13 @@ void checkToMap(Entity *e)
 		}
 	}
 
-	if (e->y > getMaxMapY() && e->y - e->dirY <= getMaxMapY())
+	if (e->y > getMapMaxY() && e->y - e->dirY <= getMapMaxY())
 	{
-		e->flags &= ~HELPLESS|INVULNERABLE;
+		e->flags &= ~(HELPLESS|INVULNERABLE);
 
 		if (e->fallout == NULL)
 		{
-			printf("%s has no fallout defined. Removing\n", self->name);
+			printf("%s has no fallout defined. Removing\n", e->name);
 
 			e->inUse = FALSE;
 
@@ -1083,7 +1083,7 @@ int isAtEdge(Entity *e)
 	int x = e->face == LEFT ? floor(e->x) : ceil(e->x) + e->w;
 	int y = e->y + e->h - 1;
 	EntityList *el, *entities;
-	
+
 	entities = getEntities();
 
 	x /= TILE_SIZE;
@@ -1274,7 +1274,7 @@ int isValidOnMap(Entity *e)
 {
 	int i, x1, x2, y1, y2;
 
-	if (e->x < getMinMapX() || e->x + e->w > getMaxMapX() || e->h < 0 || e->y + e->h > getMaxMapY())
+	if (e->x < getMapMinX() || e->x + e->w > getMapMaxX() || e->h < 0 || e->y + e->h > getMapMaxY())
 	{
 		return FALSE;
 	}
@@ -1346,7 +1346,7 @@ int isValidOnMap(Entity *e)
 
 int getMapFloor(int x, int y)
 {
-	int maxY = getMaxMapY() / TILE_SIZE;
+	int maxY = getMapMaxY() / TILE_SIZE;
 	int tileID;
 
 	x /= TILE_SIZE;
@@ -1425,7 +1425,7 @@ int getMapLeft(int x, int y)
 
 int getMapRight(int x, int y)
 {
-	int maxX = getMaxMapX() / TILE_SIZE;
+	int maxX = getMapMaxX() / TILE_SIZE;
 	int tileID;
 
 	x /= TILE_SIZE;
