@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,29 +14,29 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../graphics/animation.h"
 #include "../audio/audio.h"
-#include "../entity.h"
-#include "../custom_actions.h"
-#include "../system/properties.h"
 #include "../collisions.h"
-#include "../system/error.h"
-#include "../player.h"
-#include "../geometry.h"
+#include "../custom_actions.h"
+#include "../entity.h"
 #include "../game.h"
-#include "../system/random.h"
-#include "../world/target.h"
-#include "rock.h"
-#include "book.h"
-#include "thunder_cloud.h"
-#include "../item/item.h"
+#include "../geometry.h"
+#include "../graphics/animation.h"
 #include "../graphics/decoration.h"
 #include "../hud.h"
+#include "../item/item.h"
+#include "../player.h"
+#include "../system/error.h"
+#include "../system/properties.h"
+#include "../system/random.h"
+#include "../world/target.h"
+#include "book.h"
+#include "rock.h"
+#include "thunder_cloud.h"
 
 extern Entity *self, player;
 
@@ -127,7 +127,7 @@ Entity *addLargeBook(int x, int y, char *name)
 	{
 		e->action = &redWait;
 		e->die = &redDieInit;
-		
+
 		e->creditsAction = &creditsMove;
 	}
 
@@ -135,7 +135,7 @@ Entity *addLargeBook(int x, int y, char *name)
 	{
 		e->action = &blueWait;
 		e->die = &blueDieInit;
-		
+
 		e->creditsAction = &creditsMove;
 	}
 
@@ -143,7 +143,7 @@ Entity *addLargeBook(int x, int y, char *name)
 	{
 		e->action = &yellowWait;
 		e->die = &yellowDieInit;
-		
+
 		e->creditsAction = &creditsMove;
 	}
 
@@ -151,7 +151,7 @@ Entity *addLargeBook(int x, int y, char *name)
 	{
 		e->action = &greenWait;
 		e->die = &greenDieInit;
-		
+
 		e->creditsAction = &greenCreditsMove;
 	}
 
@@ -523,7 +523,7 @@ static void fireBounce()
 
 static void fireBlock(Entity *other)
 {
-	self->inUse = FALSE;
+	self->dirX = 0;
 }
 
 static void blueWait()
@@ -670,6 +670,7 @@ static void castIceInit()
 
 static void castIce()
 {
+	int x, y;
 	Entity *e;
 
 	self->thinkTime--;
@@ -686,48 +687,62 @@ static void castIce()
 		loadProperties("enemy/ice_spike", e);
 
 		setEntityAnimation(e, "STAND");
-
-		e->x = self->x + self->w / 2;
-		e->y = self->y + self->h / 2;
-
-		e->x -= e->w / 2;
-		e->y -= e->h / 2;
-
-		e->targetX = player.x + player.w / 2;
-		e->targetY = self->y - 100 - (prand() % 60);
-
-		calculatePath(e->x, e->y, e->targetX, e->targetY, &e->dirX, &e->dirY);
-
-		e->flags |= (NO_DRAW|HELPLESS|TELEPORTING|NO_END_TELEPORT_SOUND);
-
-		playSoundToMap("sound/common/spell.ogg", -1, self->x, self->y, 0);
-
-		e->action = &iceDrop;
-		e->draw = &drawLoopingAnimationToMap;
-		e->touch = &entityTouch;
-
-		e->head = self;
-
-		e->face = self->face;
-
-		e->type = ENEMY;
-
-		e->thinkTime = 30;
-
-		e->flags |= FLY|DO_NOT_PERSIST;
-
-		self->endX--;
-
-		if (self->endX <= 0)
+		
+		x = player.x + player.w / 2;
+		y = self->y - 100 - (prand() % 60);
+		
+		e->x = x;
+		e->y = y;
+		
+		if (isValidOnMap(e) == TRUE)
 		{
-			self->thinkTime = 0;
+			e->x = self->x + self->w / 2;
+			e->y = self->y + self->h / 2;
 
-			self->action = &castIceFinish;
+			e->x -= e->w / 2;
+			e->y -= e->h / 2;
+			
+			e->targetX = x;
+			e->targetY = y;
+			
+			calculatePath(e->x, e->y, e->targetX, e->targetY, &e->dirX, &e->dirY);
+
+			e->flags |= (NO_DRAW|HELPLESS|TELEPORTING|NO_END_TELEPORT_SOUND);
+
+			playSoundToMap("sound/common/spell.ogg", -1, self->x, self->y, 0);
+
+			e->action = &iceDrop;
+			e->draw = &drawLoopingAnimationToMap;
+			e->touch = &entityTouch;
+
+			e->head = self;
+
+			e->face = self->face;
+
+			e->type = ENEMY;
+
+			e->thinkTime = 30;
+
+			e->flags |= FLY|DO_NOT_PERSIST;
+
+			self->endX--;
+
+			if (self->endX <= 0)
+			{
+				self->thinkTime = 0;
+
+				self->action = &castIceFinish;
+			}
+
+			else
+			{
+				self->thinkTime = 30;
+			}
 		}
-
+		
 		else
 		{
-			self->thinkTime = 30;
+			e->inUse = FALSE;
 		}
 	}
 
@@ -972,6 +987,7 @@ static void castIceFinish()
 
 static void createIceBlock()
 {
+	int x, y;
 	Entity *e;
 
 	self->thinkTime--;
@@ -988,54 +1004,68 @@ static void createIceBlock()
 		loadProperties("edgar/edgar_frozen", e);
 
 		setEntityAnimation(e, "STAND");
-
-		e->x = self->x + self->w / 2;
-		e->y = self->y + self->h / 2;
-
-		e->x -= e->w / 2;
-		e->y -= e->h / 2;
-
-		e->targetX = player.x + player.w / 2;
-		e->targetY = self->y - 100 - (prand() % 60);
-
-		e->damage = 1;
-
-		e->health = 50;
-
-		calculatePath(e->x, e->y, e->targetX, e->targetY, &e->dirX, &e->dirY);
-
-		e->flags |= (NO_DRAW|HELPLESS|TELEPORTING|NO_END_TELEPORT_SOUND);
-
-		playSoundToMap("sound/common/spell.ogg", -1, self->x, self->y, 0);
-
-		e->action = &iceBlockDrop;
-		e->draw = &drawLoopingAnimationToMap;
-		e->touch = &entityTouch;
-		e->pain = &enemyPain;
-		e->die = &iceBlockDie;
-
-		e->head = self;
-
-		e->face = self->face;
-
-		e->type = ENEMY;
-
-		e->thinkTime = 30;
-
-		e->flags |= FLY|DO_NOT_PERSIST;
-
-		self->endX--;
-
-		if (self->endX <= 0)
+		
+		x = player.x + player.w / 2;
+		y = self->y - 100 - (prand() % 60);
+		
+		e->x = x;
+		e->y = y;
+		
+		if (isValidOnMap(e) == TRUE)
 		{
-			self->thinkTime = 0;
+			e->x = self->x + self->w / 2;
+			e->y = self->y + self->h / 2;
 
-			self->action = &castIceFinish;
+			e->x -= e->w / 2;
+			e->y -= e->h / 2;
+
+			e->targetX = x;
+			e->targetY = y;
+
+			e->damage = 1;
+
+			e->health = 50;
+
+			calculatePath(e->x, e->y, e->targetX, e->targetY, &e->dirX, &e->dirY);
+
+			e->flags |= (NO_DRAW|HELPLESS|TELEPORTING|NO_END_TELEPORT_SOUND);
+
+			playSoundToMap("sound/common/spell.ogg", -1, self->x, self->y, 0);
+
+			e->action = &iceBlockDrop;
+			e->draw = &drawLoopingAnimationToMap;
+			e->touch = &entityTouch;
+			e->pain = &enemyPain;
+			e->die = &iceBlockDie;
+
+			e->head = self;
+
+			e->face = self->face;
+
+			e->type = ENEMY;
+
+			e->thinkTime = 30;
+
+			e->flags |= FLY|DO_NOT_PERSIST;
+
+			self->endX--;
+
+			if (self->endX <= 0)
+			{
+				self->thinkTime = 0;
+
+				self->action = &castIceFinish;
+			}
+
+			else
+			{
+				self->thinkTime = 60;
+			}
 		}
-
+		
 		else
 		{
-			self->thinkTime = 60;
+			e->inUse = FALSE;
 		}
 	}
 
@@ -1575,8 +1605,6 @@ static void castLightningBolt()
 
 		e->face = RIGHT;
 
-		setEntityAnimation(e, "STAND");
-
 		e->action = &lightningBolt;
 
 		e->draw = &drawLoopingAnimationToMap;
@@ -1591,8 +1619,6 @@ static void castLightningBolt()
 
 		e->flags |= FLY|DO_NOT_PERSIST;
 
-		setEntityAnimation(e, "STAND");
-
 		self->endX--;
 
 		if (self->endX <= 0)
@@ -2352,42 +2378,42 @@ static void takeDamage(Entity *other, int damage)
 static void creditsMove()
 {
 	setEntityAnimation(self, "STAND");
-	
+
 	self->dirX = self->speed;
-	
+
 	checkToMap(self);
-	
+
 	if (self->dirX == 0)
 	{
 		self->inUse = FALSE;
 	}
-	
+
 	hover();
 }
 
 static void greenCreditsMove()
 {
 	self->thinkTime++;
-	
+
 	setEntityAnimation(self, "STAND");
-	
+
 	self->dirX = self->speed;
-	
+
 	checkToMap(self);
-	
+
 	if (self->dirX == 0)
 	{
 		self->inUse = FALSE;
 	}
-	
+
 	hover();
-	
+
 	if (self->thinkTime == 300)
 	{
 		self->thinkTime = 60;
-		
+
 		self->creditsAction = &creditsSummon;
-		
+
 		self->mental = 0;
 	}
 }
@@ -2395,13 +2421,13 @@ static void greenCreditsMove()
 static void creditsSummon()
 {
 	Entity *e;
-	
+
 	self->dirX = 0;
-	
+
 	hover();
-	
+
 	self->thinkTime--;
-	
+
 	if (self->thinkTime <= 0)
 	{
 		switch (self->mental)
@@ -2420,11 +2446,11 @@ static void creditsSummon()
 
 			default:
 				e = addBook(self->x, self->y, "enemy/blue_book");
-				
+
 				self->creditsAction = &creditsMove;
 			break;
 		}
-		
+
 		e->x = self->x + self->w / 2;
 		e->y = self->y + self->h / 2;
 
@@ -2433,7 +2459,7 @@ static void creditsSummon()
 
 		e->targetY = e->y + (prand() % 16) * (prand() % 2 == 0 ? -1 : 1);
 		e->targetX = e->x - SCREEN_WIDTH / 2 + (prand() % 16) * (prand() % 2 == 0 ? -1 : 1);
-		
+
 		e->startY = e->targetY;
 
 		calculatePath(e->x, e->y, e->targetX, e->targetY, &e->dirX, &e->dirY);
@@ -2443,9 +2469,9 @@ static void creditsSummon()
 		playSoundToMap("sound/common/spell.ogg", -1, self->x, self->y, 0);
 
 		e->face = RIGHT;
-		
+
 		self->mental++;
-		
+
 		self->thinkTime = 30;
 	}
 }
