@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,34 +14,29 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
-#include "entity.h"
-#include "collisions.h"
-#include "item/item.h"
-#include "custom_actions.h"
-#include "graphics/decoration.h"
-#include "event/trigger.h"
-#include "event/global_trigger.h"
-#include "system/properties.h"
-#include "enemy/enemies.h"
-#include "item/key_items.h"
-#include "event/script.h"
-#include "graphics/animation.h"
-#include "player.h"
-#include "system/random.h"
 #include "audio/audio.h"
-#include "geometry.h"
-#include "hud.h"
-#include "system/error.h"
+#include "collisions.h"
+#include "custom_actions.h"
+#include "entity.h"
+#include "event/global_trigger.h"
+#include "event/script.h"
+#include "event/trigger.h"
 #include "game.h"
-#include "world/action_point.h"
-#include "world/falling_platform.h"
-#include "world/weak_wall.h"
-#include "world/npc.h"
+#include "geometry.h"
+#include "graphics/animation.h"
+#include "graphics/decoration.h"
+#include "hud.h"
+#include "item/item.h"
+#include "player.h"
+#include "system/error.h"
+#include "system/properties.h"
+#include "system/random.h"
+#include "system/resources.h"
 
 extern Entity *self;
 extern Game game;
@@ -68,7 +63,7 @@ void freeEntities()
 			{
 				free(p->entity);
 			}
-			
+
 			q = p->next;
 
 			free(p);
@@ -76,7 +71,7 @@ void freeEntities()
 
 		free(entities);
 	}
-	
+
 	entities = malloc(sizeof(EntityList));
 
 	if (entities == NULL)
@@ -85,21 +80,21 @@ void freeEntities()
 	}
 
 	entities->next = NULL;
-	
+
 	clearDrawLayers();
 }
 
 Entity *getFreeEntity()
 {
 	Entity *e;
-	
+
 	e = malloc(sizeof(Entity));
-	
+
 	if (e == NULL)
 	{
 		showErrorAndExit("Failed to allocate %d bytes for an Entity", (int)sizeof(Entity));
 	}
-	
+
 	memset(e, 0, sizeof(Entity));
 
 	e->inUse = TRUE;
@@ -121,13 +116,13 @@ Entity *getFreeEntity()
 	e->alpha = 255;
 
 	addEntityToList(entities, e);
-	
+
 	return e;
 }
 
 void doEntities()
 {
-	int i, removeCount;
+	int i;
 	EntityList *el;
 
 	/* Loop through the entities and perform their action */
@@ -254,34 +249,12 @@ void doEntities()
 			addToDrawLayer(self, self->layer);
 		}
 	}
-	
-	if (game.frames % 300 == 0)
-	{
-		removeCount = 0;
-		
-		for (el=entities->next;el!=NULL;el=el->next)
-		{
-			if (el->entity->inUse == FALSE && isReferenced(el->entity) == FALSE)
-			{
-				removeEntityFromList(entities, el->entity);
-				
-				removeCount++;
-			}
-		}
-		
-		#if DEV == 1
-		if (removeCount != 0)
-		{
-			printf("Removed %d entities taking up %d bytes\n", removeCount, (int)sizeof(Entity) * removeCount);
-		}
-		#endif
-	}
 }
 
 void drawEntities(int depth)
 {
-	int i, drawn;
-	EntityList *el;
+	int i, drawn, removeCount;
+	EntityList *el, *prev, *el2;
 
 	/* Draw standard entities */
 
@@ -344,6 +317,45 @@ void drawEntities(int depth)
 			}
 		}
 	}
+
+	if (game.frames % 300 == 0)
+	{
+		removeCount = 0;
+
+		prev = entities;
+
+		for (el=entities->next;el!=NULL;el=el2)
+		{
+			el2 = el->next;
+
+			if (el->entity->inUse == FALSE && isReferenced(el->entity) == FALSE)
+			{
+				prev->next = el2;
+
+				removeCount++;
+
+				free(el->entity);
+
+				el->entity = NULL;
+
+				free(el);
+
+				el = NULL;
+			}
+
+			else
+			{
+				prev = prev->next;
+			}
+		}
+
+		#if DEV == 1
+		if (removeCount != 0)
+		{
+			printf("Removed %d entities taking up %d bytes\n", removeCount, (int)sizeof(Entity) * removeCount);
+		}
+		#endif
+	}
 }
 
 void removeEntity()
@@ -732,7 +744,7 @@ void enemyPain()
 void entityTouch(Entity *other)
 {
 	Entity *temp;
-	
+
 	if (other->type == PLAYER && self->parent != other && self->damage != 0)
 	{
 		temp = self;
@@ -770,7 +782,7 @@ void pushEntity(Entity *other)
 	static int depth = 0;
 	long wasOnGround;
 
-	if (other->touch == NULL || (other->type == WEAPON && other->flags & ATTACKING) || (other->flags & PLAYER_TOUCH_ONLY))
+	if (other->touch == NULL || (other->type == WEAPON && (other->flags & ATTACKING)) || (other->flags & PLAYER_TOUCH_ONLY))
 	{
 		return;
 	}
@@ -1054,30 +1066,7 @@ void pushEntity(Entity *other)
 			collided = TRUE;
 		}
 	}
-	/*
-	else if (collided == FALSE)
-	{
-		if (self->x > other->x && depth == 1)
-		{
-			Place the entity as close as possible
 
-			self->x = getRightEdge(other);
-
-			self->dirX = 0;
-		}
-
-		else if (depth == 1)
-		{
-			Place the entity as close as possible
-
-			self->x = getLeftEdge(other);
-
-			self->x -= self->box.w;
-
-			self->dirX = 0;
-		}
-	}
-	*/
 	other->x += other->dirX;
 	other->y += other->dirY;
 }
@@ -1085,7 +1074,7 @@ void pushEntity(Entity *other)
 Entity *addEntity(Entity e, int x, int y)
 {
 	Entity *ent;
-	
+
 	ent = getFreeEntity();
 
 	memcpy(ent, &e, sizeof(Entity));
@@ -1253,6 +1242,21 @@ Entity *getEntityByStartXY(int x, int y)
 	return NULL;
 }
 
+Entity *getEntityByXY(int x, int y)
+{
+	EntityList *el;
+
+	for (el=entities->next;el!=NULL;el=el->next)
+	{
+		if (el->entity->inUse == TRUE && el->entity->x == x && el->entity->y == y)
+		{
+			return el->entity;
+		}
+	}
+
+	return NULL;
+}
+
 void activateEntitiesWithRequiredName(char *name, int active)
 {
 	EntityList *el;
@@ -1360,11 +1364,7 @@ void initLineDefs()
 
 void changeDirection(Entity *other)
 {
-	self->dirX *= -1;
-
-	checkToMap(self);
-
-	self->face = self->face == RIGHT ? LEFT : RIGHT;
+	self->dirX = 0;
 }
 
 void writeEntitiesToFile(FILE *fp)
@@ -1420,82 +1420,23 @@ void addEntityFromScript(char *line)
 
 	sscanf(line, "%s %s \"%[^\"]\" %d %d", entityType, entityName, objectiveName, &x, &y);
 
-	if (strcmpignorecase(entityType, "WEAPON") == 0 || strcmpignorecase(entityType, "SHIELD") == 0 ||
-		strcmpignorecase(entityType, "ITEM") == 0)
+	e = addEntityFromResource(entityType, entityName, x, y);
+
+	e->startX = x;
+	e->startY = y;
+	e->endX = x;
+	e->endY = y;
+
+	if (strcmpignorecase(objectiveName, " ") != 0)
 	{
-		e = addPermanentItem(entityName, x, y);
-
-		if (strcmpignorecase(objectiveName, " ") != 0)
-		{
-			STRNCPY(e->objectiveName, objectiveName, sizeof(e->objectiveName));
-		}
-	}
-
-	else if (strcmpignorecase(entityType, "KEY_ITEM") == 0)
-	{
-		e = addKeyItem(entityName, x, y);
-
-		if (strcmpignorecase(objectiveName, " ") != 0)
-		{
-			STRNCPY(e->objectiveName, objectiveName, sizeof(e->objectiveName));
-		}
-	}
-	
-	else if (strcmpignorecase(entityType, "NPC") == 0)
-	{
-		e = addNPC(entityName, x, y);
-
-		if (strcmpignorecase(objectiveName, " ") != 0)
-		{
-			STRNCPY(e->objectiveName, objectiveName, sizeof(e->objectiveName));
-		}
-	}
-
-	else if (strcmpignorecase(entityType, "ENEMY") == 0)
-	{
-		e = addEnemy(entityName, x, y);
-		
-		if (strcmpignorecase(objectiveName, " ") != 0)
-		{
-			STRNCPY(e->objectiveName, objectiveName, sizeof(e->objectiveName));
-		}
-	}
-
-	else if (strcmpignorecase(entityType, "ACTION_POINT") == 0)
-	{
-		e = addActionPoint("common/action_point", x, y);
-
-		e->startX = x;
-		e->startY = y;
-		e->endX = x;
-		e->endY = y;
-
-		if (strcmpignorecase(objectiveName, " ") != 0)
-		{
-			STRNCPY(e->objectiveName, objectiveName, sizeof(e->objectiveName));
-		}
-	}
-
-	else if (strcmpignorecase(entityType, "FALLING_PLATFORM") == 0)
-	{
-		addFallingPlatform(x, y, entityName);
-	}
-
-	else if (strcmpignorecase(entityType, "WEAK_WALL") == 0)
-	{
-		addWeakWall(entityName, x, y);
-	}
-
-	else
-	{
-		showErrorAndExit("ADD ENTITY command encountered unknown entity %s", entityType);
+		STRNCPY(e->objectiveName, objectiveName, sizeof(e->objectiveName));
 	}
 }
 
 void entityWalkTo(Entity *e, char *coords)
 {
 	int x, y, read;
-	char wait[10], anim[10];
+	char wait[10], anim[20];
 
 	read = sscanf(coords, "%d %d %s %s", &x, &y, wait, anim);
 
@@ -1540,13 +1481,13 @@ void entityWalkTo(Entity *e, char *coords)
 void entityWalkToEntity(Entity *e, char *coords)
 {
 	int read;
-	char wait[10], anim[10], entityName[MAX_VALUE_LENGTH];
+	char wait[10], anim[20], entityName[MAX_VALUE_LENGTH];
 	Entity *e2;
 
 	read = sscanf(coords, "%s %s %s", entityName, wait, anim);
-	
+
 	e2 = getEntityByObjectiveName(entityName);
-	
+
 	if (e2 == NULL)
 	{
 		showErrorAndExit("Could not find Entity %s to walk to", entityName);
@@ -1593,7 +1534,7 @@ void entityWalkToEntity(Entity *e, char *coords)
 void entityWalkToRelative(Entity *e, char *coords)
 {
 	int x, y, read;
-	char wait[10], anim[10];
+	char wait[10], anim[20];
 
 	read = sscanf(coords, "%d %d %s %s", &x, &y, wait, anim);
 
@@ -1894,6 +1835,11 @@ void addEntityToList(EntityList *head, Entity *e)
 
 	list = malloc(sizeof(EntityList));
 
+	if (list == NULL)
+	{
+		showErrorAndExit("Failed to allocate a whole %d bytes for Entity List", (int)sizeof(EntityList));
+	}
+
 	list->entity = e;
 	list->next = NULL;
 
@@ -1912,7 +1858,35 @@ void killEntity(char *name)
 
 int atTarget()
 {
-	if (fabs(self->targetX - self->x) <= fabs(self->dirX) && fabs(self->targetY - self->y) <= fabs(self->dirY))
+	if (fabs(self->dirY) > 0 && fabs(self->dirY) < 0.01)
+	{
+		if (fabs(self->targetX - self->x) <= fabs(self->dirX))
+		{
+			self->x = self->targetX;
+			self->y = self->targetY;
+
+			self->dirX = 0;
+			self->dirY = 0;
+
+			return TRUE;
+		}
+	}
+
+	else if (fabs(self->dirX) > 0 && fabs(self->dirX) < 0.01)
+	{
+		if (fabs(self->targetY - self->y) <= fabs(self->dirY))
+		{
+			self->x = self->targetX;
+			self->y = self->targetY;
+
+			self->dirX = 0;
+			self->dirY = 0;
+
+			return TRUE;
+		}
+	}
+
+	else if (fabs(self->targetX - self->x) <= fabs(self->dirX) && fabs(self->targetY - self->y) <= fabs(self->dirY))
 	{
 		self->x = self->targetX;
 		self->y = self->targetY;
@@ -1933,6 +1907,11 @@ void faceTarget()
 
 void addToDrawLayer(Entity *e, int layer)
 {
+	if (e->inUse == FALSE)
+	{
+		return;
+	}
+
 	drawLayer[layer][drawLayerIndex[layer]] = e;
 
 	drawLayerIndex[layer]++;
@@ -1975,9 +1954,9 @@ int landedOnGround(long wasOnGround)
 void creditsMove()
 {
 	self->dirX = self->speed;
-	
+
 	checkToMap(self);
-	
+
 	if (self->dirX == 0)
 	{
 		self->inUse = FALSE;
@@ -1988,48 +1967,48 @@ void addDuplicateImage(Entity *e)
 {
 	char shadowAnim[MAX_VALUE_LENGTH];
 	Entity *duplicate;
-	
+
 	duplicate = getFreeEntity();
-	
+
 	if (duplicate == NULL)
 	{
 		return;
 	}
-	
+
 	loadProperties(e->name, duplicate);
-	
+
 	duplicate->x = e->x;
 	duplicate->y = e->y;
-	
+
 	duplicate->thinkTime = 15;
-	
+
 	duplicate->draw = &drawLoopingAnimationToMap;
-	
+
 	duplicate->action = &duplicateWait;
-	
+
 	duplicate->creditsAction = &duplicateWait;
-	
+
 	snprintf(shadowAnim, MAX_VALUE_LENGTH, "%s_SHADOW", getAnimationTypeAtIndex(e));
-	
+
 	setEntityAnimation(duplicate, shadowAnim);
-	
+
 	duplicate->currentFrame = e->currentFrame;
-	
+
 	duplicate->frameSpeed = 0;
-	
+
 	duplicate->face = e->face;
-	
+
 	duplicate->layer = BACKGROUND_LAYER;
-	
+
 	duplicate->flags |= DO_NOT_PERSIST;
-	
+
 	duplicate->head = e;
 }
 
 static void duplicateWait()
 {
 	self->thinkTime--;
-	
+
 	if (self->thinkTime <= 0)
 	{
 		self->inUse = FALSE;
@@ -2044,41 +2023,14 @@ EntityList *getEntities()
 static int isReferenced(Entity *e)
 {
 	EntityList *el;
-	
+
 	for (el=entities->next;el!=NULL;el=el->next)
 	{
-		if (el->entity->head == e || el->entity->target == e || el->entity->standingOn == e || el->entity->head == e)
+		if (el->entity->head == e || el->entity->target == e || el->entity->standingOn == e)
 		{
 			return TRUE;
 		}
 	}
-	
+
 	return FALSE;
 }
-
-void removeEntityFromList(EntityList *list, Entity *e)
-{
-	EntityList *prev, *el;
-	
-	prev = list;
-	
-	for (el=list->next;el!=NULL;el=el->next)
-	{
-		if (el->entity == e)
-		{
-			free(el->entity);
-			
-			el->entity = NULL;
-			
-			prev->next = el->next;
-			
-			free(el);
-			
-			el = NULL;
-			
-			return;
-		}
-		
-		prev = el;
-	}
-}
