@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,14 +14,12 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 void fireMapTrigger(char *);
 void writeMapTriggersToFile(FILE *);
 void addMapTriggerFromResource(char *[], char *[]);
 void freeMapTriggers(void);
-int getMapTriggerTypeByName(char *);
-char *getMapTriggerTypeByID(int);
 void updateMapTrigger(char *, int);
 void addMapTriggerFromScript(char *);
