@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,34 +14,34 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
+#include "../audio/audio.h"
+#include "../audio/music.h"
+#include "../custom_actions.h"
+#include "../dialog.h"
+#include "../entity.h"
 #include "../event/global_trigger.h"
 #include "../event/map_trigger.h"
 #include "../event/objective.h"
-#include "../entity.h"
-#include "script.h"
-#include "../dialog.h"
-#include "../player.h"
-#include "../inventory.h"
-#include "../audio/audio.h"
-#include "../audio/music.h"
-#include "../graphics/decoration.h"
-#include "../graphics/animation.h"
 #include "../game.h"
+#include "../graphics/animation.h"
+#include "../graphics/decoration.h"
+#include "../inventory.h"
 #include "../map.h"
-#include "../system/properties.h"
-#include "../system/pak.h"
-#include "../custom_actions.h"
-#include "../system/random.h"
+#include "../medal.h"
+#include "../menu/script_menu.h"
+#include "../player.h"
 #include "../system/error.h"
 #include "../system/load_save.h"
-#include "../medal.h"
+#include "../system/pak.h"
+#include "../system/properties.h"
+#include "../system/random.h"
 #include "../weather.h"
-#include "../menu/script_menu.h"
+#include "script.h"
 
 extern Entity player, *self;
 extern Game game;
@@ -324,7 +324,7 @@ void readNextScriptLine()
 					script.skipping = TRUE;
 				}
 			}
-			
+
 			else if (strcmpignorecase(token, "CHEATING") == 0)
 			{
 				if (game.cheating == FALSE)
@@ -332,7 +332,7 @@ void readNextScriptLine()
 					script.skipping = TRUE;
 				}
 			}
-			
+
 			else if (strcmpignorecase(token, "NOT_CHEATING") == 0)
 			{
 				if (game.cheating == TRUE)
@@ -381,6 +381,63 @@ void readNextScriptLine()
 				}
 			}
 
+			else if (strcmpignorecase(token, "EQUALS") == 0)
+			{
+				token = strtok_r(NULL, " ", &savePtr);
+
+				token2 = strtok_r(NULL, " ", &savePtr);
+
+				val = -1;
+
+				if (strcmpignorecase(token, "[CONTINUE_COUNT]") == 0)
+				{
+					val = game.continues;
+				}
+
+				if (val != atoi(token2))
+				{
+					script.skipping = TRUE;
+				}
+			}
+
+			else if (strcmpignorecase(token, "GREATER_THAN") == 0)
+			{
+				token = strtok_r(NULL, " ", &savePtr);
+
+				token2 = strtok_r(NULL, " ", &savePtr);
+
+				val = -1;
+
+				if (strcmpignorecase(token, "[CONTINUE_COUNT]") == 0)
+				{
+					val = game.continues;
+				}
+
+				if (val <= atoi(token2))
+				{
+					script.skipping = TRUE;
+				}
+			}
+
+			else if (strcmpignorecase(token, "LESS_THAN") == 0)
+			{
+				token = strtok_r(NULL, " ", &savePtr);
+
+				token2 = strtok_r(NULL, " ", &savePtr);
+
+				val = -1;
+
+				if (strcmpignorecase(token, "[CONTINUE_COUNT]") == 0)
+				{
+					val = game.continues;
+				}
+
+				if (val > atoi(token2))
+				{
+					script.skipping = TRUE;
+				}
+			}
+
 			else
 			{
 				if (strcmpignorecase(token, "EDGAR") == 0)
@@ -500,7 +557,7 @@ void readNextScriptLine()
 			}
 		}
 
-		else if (strcmpignorecase("WHILE", command) == 0)
+		else if (strcmpignorecase("WHILE", command) == 0 || strcmpignorecase("WHILE_NOT", command) == 0)
 		{
 			token = strtok_r(NULL, " ", &savePtr);
 
@@ -519,7 +576,7 @@ void readNextScriptLine()
 					script.line--;
 				}
 			}
-			
+
 			else if (strcmpignorecase(token, "NOT_EXISTS") == 0)
 			{
 				token = strtok_r(NULL, " ", &savePtr);
@@ -565,7 +622,8 @@ void readNextScriptLine()
 
 					val = atoi(token);
 
-					if (e->health == val)
+					if ((strcmpignorecase("WHILE", command) == 0 && e->health == val) ||
+						(strcmpignorecase("WHILE_NOT", command) == 0 && e->health != val))
 					{
 						freeDialogBox();
 
@@ -581,7 +639,8 @@ void readNextScriptLine()
 
 					val = atoi(token);
 
-					if (e->mental == val)
+					if ((strcmpignorecase("WHILE", command) == 0 && e->mental == val) ||
+						(strcmpignorecase("WHILE_NOT", command) == 0 && e->mental != val))
 					{
 						freeDialogBox();
 
@@ -710,6 +769,18 @@ void readNextScriptLine()
 					syncWeaponShieldToPlayer();
 				}
 			}
+			
+			else if (strcmpignorecase(token, "PROPERTIES") == 0)
+			{
+				token = strtok_r(NULL, " ", &savePtr);
+
+				loadProperties(token, e);
+
+				if (e == &player)
+				{
+					syncWeaponShieldToPlayer();
+				}
+			}
 
 			else if (strcmpignorecase(token, "SPEED") == 0)
 			{
@@ -802,28 +873,28 @@ void readNextScriptLine()
 
 			setWeaponFromScript(token);
 		}
-		
+
 		else if (strcmpignorecase("EQUIP_SHIELD", command) == 0)
 		{
 			token = strtok_r(NULL, "\0", &savePtr);
 
 			setShieldFromScript(token);
 		}
-		
+
 		else if (strcmpignorecase("UNEQUIP_WEAPON", command) == 0)
 		{
 			unsetWeapon();
 		}
-		
+
 		else if (strcmpignorecase("UNEQUIP_SHIELD", command) == 0)
 		{
 			unsetShield();
 		}
-		
+
 		else if (strcmpignorecase("WEATHER", command) == 0)
 		{
 			token = strtok_r(NULL, "\0", &savePtr);
-			
+
 			setWeather(getWeatherTypeByName(token));
 		}
 
@@ -848,7 +919,7 @@ void readNextScriptLine()
 
 			setNextLevelFromScript(token);
 		}
-		
+
 		else if (strcmpignorecase("SHOW_CREDITS", command) == 0)
 		{
 			showEndCredits();
@@ -886,7 +957,7 @@ void readNextScriptLine()
 
 			becomeJumpingSlime(atoi(token));
 		}
-		
+
 		else if (strcmpignorecase("FIRE_TRIGGER", command) == 0)
 		{
 			token = strtok_r(NULL, "\0", &savePtr);
@@ -943,15 +1014,22 @@ void readNextScriptLine()
 				token = strtok_r(NULL, "\0", &savePtr);
 
 				loadMusic(token);
-				
+
 				playLoadedMusic();
 			}
-			
+
+			else if (strcmpignorecase("PLAY_BOSS_MUSIC", token) == 0)
+			{
+				playDefaultBossMusic();
+
+				playLoadedMusic();
+			}
+
 			else if (strcmpignorecase("OVERRIDE", token) == 0)
 			{
 				game.overrideMusic = TRUE;
 			}
-			
+
 			else if (strcmpignorecase("REMOVE_OVERRIDE", token) == 0)
 			{
 				game.overrideMusic = FALSE;
@@ -1104,7 +1182,7 @@ void readNextScriptLine()
 			{
 				entityWalkTo(e, token);
 			}
-			
+
 			else if (strcmpignorecase("WALK_TO_ENTITY", command) == 0)
 			{
 				entityWalkToEntity(e, token);
@@ -1244,11 +1322,11 @@ void readNextScriptLine()
 		{
 			resetCameraLimits();
 		}
-		
+
 		else if (strcmpignorecase("CAMERA_SNAP", command) == 0)
 		{
 			token = strtok_r(NULL, " ", &savePtr);
-			
+
 			if (strcmpignorecase(token, "EDGAR") == 0)
 			{
 				e = &player;
@@ -1258,9 +1336,9 @@ void readNextScriptLine()
 			{
 				e = getEntityByObjectiveName(token);
 			}
-			
+
 			centerMapOnEntity(e);
-			
+
 			cameraSnapToTargetEntity();
 		}
 
@@ -1270,6 +1348,13 @@ void readNextScriptLine()
 
 			setCameraSpeed(atof(token));
 		}
+		
+		else if (strcmpignorecase("CAMERA_START", command) == 0)
+		{
+			token = strtok_r(NULL, "\0", &savePtr);
+
+			setCameraPositionFromScript(token);
+		}
 
 		else if (strcmpignorecase("RUN_SCRIPT", command) == 0)
 		{
@@ -1277,7 +1362,7 @@ void readNextScriptLine()
 
 			runScript(token);
 		}
-		
+
 		else if (strcmpignorecase("HUD", command) == 0)
 		{
 			token = strtok_r(NULL, "\0", &savePtr);
@@ -1286,7 +1371,7 @@ void readNextScriptLine()
 			{
 				game.showHUD = FALSE;
 			}
-			
+
 			else
 			{
 				game.showHUD = TRUE;
