@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,30 +14,29 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
-#include "game.h"
-#include "medal.h"
-#include "system/random.h"
 #include "audio/audio.h"
 #include "audio/music.h"
-#include "graphics/graphics.h"
-#include "system/resources.h"
-#include "map.h"
-#include "hud.h"
-#include "system/load_save.h"
 #include "entity.h"
-#include "player.h"
-#include "menu/menu.h"
-#include "menu/main_menu.h"
-#include "menu/io_menu.h"
-#include "inventory.h"
 #include "event/map_trigger.h"
+#include "game.h"
+#include "graphics/graphics.h"
+#include "hud.h"
+#include "inventory.h"
+#include "map.h"
+#include "medal.h"
+#include "menu/io_menu.h"
+#include "menu/main_menu.h"
+#include "menu/menu.h"
+#include "player.h"
 #include "system/error.h"
 #include "system/load_save.h"
+#include "system/random.h"
+#include "system/resources.h"
 
 extern Game game;
 extern Entity *self;
@@ -95,15 +94,21 @@ void initGame()
 	game.continues = 0;
 
 	game.secretsFound = 0;
-	
+
 	game.cheating = FALSE;
 
+	game.infiniteArrows = FALSE;
+
+	game.infiniteEnergy = FALSE;
+
+	game.lavaIsFatal = TRUE;
+
 	game.mapExitable = 0;
 
 	game.canContinue = FALSE;
-	
+
 	game.overrideMusic = FALSE;
-	
+
 	game.showHUD = TRUE;
 
 	game.offsetX = game.offsetY = 0;
@@ -135,7 +140,7 @@ void doGame()
 	/* Execute the action if there is one */
 
 	doGameOver();
-	
+
 	fadeToNormal();
 
 	if (game.shakeThinkTime > 0 || game.shakeThinkTime == -1)
@@ -313,6 +318,8 @@ static void wipeOutRightToLeft()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -332,6 +339,8 @@ static void wipeOutLeftToRight()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -351,6 +360,8 @@ static void wipeInLeftToRight()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -370,6 +381,8 @@ static void wipeInRightToLeft()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -389,6 +402,8 @@ static void wipeInCircleToLarge()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -408,6 +423,8 @@ static void wipeInCircleToSmall()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -427,6 +444,8 @@ static void wipeOutCircleToLarge()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -446,6 +465,8 @@ static void wipeOutCircleToSmall()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -465,6 +486,8 @@ static void creditsWipeOut()
 
 		if (game.transitionCallback != NULL)
 		{
+			clearScreen(0, 0, 0);
+
 			game.transitionCallback();
 		}
 
@@ -474,13 +497,13 @@ static void creditsWipeOut()
 	drawCircleFromSurface(SCREEN_WIDTH / 2, SCREEN_HEIGHT / 2, game.transitionX < 0 ? 0 : game.transitionX);
 
 	game.transitionX -= 5;
-	
+
 	if (game.transitionX <= spotlightSize() / 2)
 	{
 		if (game.transitionY > 0)
 		{
 			game.transitionX = spotlightSize() / 2;
-			
+
 			game.transitionY--;
 		}
 	}
@@ -502,7 +525,7 @@ void setNextLevelFromScript(char *token)
 	setNextLevel(name, playerStart);
 
 	setTransition(TRANSITION_OUT, &goToNextMap);
-	
+
 	if (game.overrideMusic == FALSE)
 	{
 		fadeOutMusic(1000);
@@ -512,19 +535,17 @@ void setNextLevelFromScript(char *token)
 void showEndCredits()
 {
 	game.overrideMusic = FALSE;
-	
+
 	game.transitionX = SCREEN_WIDTH;
 	game.transitionY = 120;
 	game.transition = &creditsWipeOut;
-	
+
 	game.transitionCallback = &initEndCredits;
 }
 
 static void initEndCredits()
 {
 	game.status = IN_CREDITS;
-	
-	clearScreen(0, 0, 0);
 }
 
 void goToNextMap()
@@ -587,8 +608,11 @@ void pauseGame()
 	switch (game.status)
 	{
 		case IN_GAME:
+		case IN_TITLE:
 			game.paused = TRUE;
 
+			game.previousStatus = game.status;
+
 			game.status = IN_MENU;
 
 			game.menu = initMainMenu();
@@ -600,16 +624,18 @@ void pauseGame()
 				SDL_BlitSurface(game.screen, NULL, game.pauseSurface, NULL);
 			}
 
-			pauseMusic(TRUE);
+			if (game.previousStatus == IN_GAME)
+			{
+				pauseMusic(TRUE);
 
-			pauseSound(TRUE);
+				pauseSound(TRUE);
+			}
 		break;
 
 		case IN_EDITOR:
 			exit(0);
 		break;
 
-		case IN_TITLE:
 		case IN_INVENTORY:
 		case IN_CREDITS:
 			/* Do nothing */
@@ -627,7 +653,7 @@ void pauseGame()
 
 				game.paused = FALSE;
 
-				game.status = IN_GAME;
+				game.status = game.previousStatus;
 
 				game.menu = initMainMenu();
 
@@ -722,13 +748,9 @@ void writeGameSettingsToFile(FILE *fp)
 	fprintf(fp, "HINTS %d\n", game.showHints);
 	fprintf(fp, "FULLSCREEN %d\n", game.fullscreen);
 	fprintf(fp, "AUDIO_QUALITY %d\n", game.audioQuality);
-	
-	if (strlen(game.customFont) != 0)
-	{
-		fprintf(fp, "FONT %s\n", game.customFont);
-		fprintf(fp, "SMALL_FONT_SIZE %d\n", game.fontSizeSmall);
-		fprintf(fp, "LARGE_FONT_SIZE %d\n", game.fontSizeLarge);
-	}
+	fprintf(fp, "FONT %s\n", game.customFont);
+	fprintf(fp, "SMALL_FONT_SIZE %d\n", game.fontSizeSmall == 0 ? NORMAL_FONT_SIZE : game.fontSizeSmall);
+	fprintf(fp, "LARGE_FONT_SIZE %d\n", game.fontSizeLarge == 0 ? LARGE_FONT_SIZE : game.fontSizeLarge);
 }
 
 void readGameSettingsFromFile(char *buffer)
@@ -747,80 +769,105 @@ void readGameSettingsFromFile(char *buffer)
 		{
 			token = strtok(NULL, "\0");
 
-			game.audio = atoi(token);
+			if (token != NULL)
+			{
+				game.audio = atoi(token);
+			}
 		}
 
 		else if (strcmpignorecase(token, "SFX_VOLUME") == 0)
 		{
 			token = strtok(NULL, "\0");
 
-			game.sfxDefaultVolume = atoi(token);
+			if (token != NULL)
+			{
+				game.sfxDefaultVolume = atoi(token);
+			}
 		}
 
 		else if (strcmpignorecase(token, "MUSIC_VOLUME") == 0)
 		{
 			token = strtok(NULL, "\0");
 
-			game.musicDefaultVolume = atoi(token);
+			if (token != NULL)
+			{
+				game.musicDefaultVolume = atoi(token);
+			}
 		}
 
 		else if (strcmpignorecase(token, "HINTS") == 0)
 		{
 			token = strtok(NULL, "\0");
 
-			game.showHints = atoi(token);
+			if (token != NULL)
+			{
+				game.showHints = atoi(token);
+			}
 		}
 
 		else if (strcmpignorecase(token, "FULLSCREEN") == 0)
 		{
 			token = strtok(NULL, "\0");
 
-			game.fullscreen = atoi(token);
+			if (token != NULL)
+			{
+				game.fullscreen = atoi(token);
+			}
 		}
 
 		else if (strcmpignorecase(token, "AUDIO_QUALITY") == 0)
 		{
 			token = strtok(NULL, "\0");
 
-			game.audioQuality = atoi(token);
+			if (token != NULL)
+			{
+				game.audioQuality = atoi(token);
+			}
 
 			if (game.audioQuality == 0)
 			{
 				game.audioQuality = 22050;
 			}
 		}
-		
+
 		else if (strcmpignorecase(token, "FONT") == 0)
 		{
 			token = strtok(NULL, "\0");
-			
-			STRNCPY(game.customFont, token, MAX_FILE_LENGTH);
+
+			if (token != NULL)
+			{
+				STRNCPY(game.customFont, token, MAX_FILE_LENGTH);
+			}
 		}
-		
+
 		else if (strcmpignorecase(token, "SMALL_FONT_SIZE") == 0)
 		{
-			token = strtok(NULL, "\0");
+			if (token != NULL)
+			{
+				token = strtok(NULL, "\0");
+			}
 
 			game.fontSizeSmall = atoi(token);
 		}
-		
+
 		else if (strcmpignorecase(token, "LARGE_FONT_SIZE") == 0)
 		{
-			token = strtok(NULL, "\0");
+			if (token != NULL)
+			{
+				token = strtok(NULL, "\0");
+			}
 
 			game.fontSizeLarge = atoi(token);
 		}
 
 		line = strtok_r(NULL, "\n", &savePtr);
 	}
-	
+
 	if (strlen(game.customFont) != 0)
 	{
 		if (game.fontSizeSmall <= 0 || game.fontSizeLarge <= 0)
 		{
-			printf(_("SMALL_FONT_SIZE and LARGE_FONT_SIZE must be specified when using a custom font"));
-			
-			exit(1);
+			showErrorAndExit(_("SMALL_FONT_SIZE and LARGE_FONT_SIZE must be specified when using a custom font"));
 		}
 	}
 }
@@ -832,14 +879,14 @@ void initGameOver()
 		game.gameOverSurface = loadImage("gfx/common/gameover.png");
 	}
 
-	game.transitionX = 0;
+	game.gameOverX = 0;
 }
 
 void doGameOver()
 {
 	if (game.gameOverSurface != NULL)
 	{
-		game.transitionX += 3;
+		game.gameOverX += 3;
 	}
 }
 
@@ -847,12 +894,12 @@ void drawGameOver()
 {
 	if (game.gameOverSurface != NULL)
 	{
-		if (game.transitionX >= game.gameOverSurface->w)
+		if (game.gameOverX >= game.gameOverSurface->w)
 		{
-			game.transitionX = game.gameOverSurface->w;
+			game.gameOverX = game.gameOverSurface->w;
 		}
 
-		drawClippedImage(game.gameOverSurface, 0, 0, (SCREEN_WIDTH - game.gameOverSurface->w) / 2, (SCREEN_HEIGHT - game.gameOverSurface->h) / 2, game.transitionX, game.gameOverSurface->h);
+		drawClippedImage(game.gameOverSurface, 0, 0, (SCREEN_WIDTH - game.gameOverSurface->w) / 2, (SCREEN_HEIGHT - game.gameOverSurface->h) / 2, game.gameOverX, game.gameOverSurface->h);
 	}
 }
 
@@ -1010,6 +1057,11 @@ void increaseSecretsFound()
 	setInfoBoxMessage(90, 0, 255, 0, _("You found a secret!"));
 
 	playSound("sound/common/secret.ogg");
+
+	if (game.secretsFound == TOTAL_SECRETS)
+	{
+		addMedal("all_secrets");
+	}
 }
 
 void setContinuePoint(int cameraFollow, char *boss, void (*resumeAction)(void))
@@ -1048,7 +1100,7 @@ void getContinuePoint()
 	setMapStartY(continueData.cameraMinY);
 
 	setCameraPosition(continueData.cameraMinX, continueData.cameraMinY);
-	
+
 	limitPlayerToCameraLimits();
 
 	if (continueData.cameraFollow == FALSE)
