@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,19 +14,18 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "../map.h"
 #include "../collisions.h"
-#include "../system/pak.h"
-#include "graphics.h"
-#include "decoration.h"
 #include "../entity.h"
-#include "../system/random.h"
+#include "../map.h"
 #include "../system/error.h"
+#include "../system/pak.h"
+#include "decoration.h"
+#include "graphics.h"
 
 extern Game game;
 extern Entity *self;
@@ -35,6 +34,9 @@ static void drawImageWhite(SDL_Surface *, int, int);
 static Uint32 getPixel(SDL_Surface *, int, int);
 static void putPixel(SDL_Surface *, int, int, Uint32);
 
+static char screenshotPath[MAX_PATH_LENGTH];
+static int frame = 0;
+
 SDL_Surface *loadImage(char *name)
 {
 	/* Load the image using SDL Image */
@@ -120,44 +122,36 @@ void drawClippedImage(SDL_Surface *image, int srcX, int srcY, int destX, int des
 
 	SDL_BlitSurface(image, &src, game.screen, &dest);
 }
-/*
-void drawFlippedImage(SDL_Surface *image, int destX, int destY, int white, int alpha)
+
+SDL_Surface *copyImage(SDL_Surface *image, int x, int y, int w, int h)
 {
-	unsigned char r, g, b;
-	int *pixels, x, y, pixel, rx, ry;
-	int color = SDL_MapRGB(game.screen->format, 255, 255, 255);
-	SDL_Rect dest;
+	int x1, y1, x2, y2;
+	Uint32 pixel;
 	SDL_Surface *flipped;
 
-	flipped = createSurface(image->w, image->h);
+	flipped = createSurface(w, h);
 
 	if (SDL_MUSTLOCK(image))
 	{
 		SDL_LockSurface(image);
 	}
 
-	for (x=0, rx=flipped->w-1;x<flipped->w;x++, rx--)
+	x2 = y2 = 0;
+
+	for (y1=y;y1<y+h;y1++)
 	{
-		for (y=0, ry=flipped->h-1;y<flipped->h;y++, ry--)
+		for (x1=x;x1<x+w;x1++)
 		{
-			pixels = (int *)image->pixels;
+			pixel = getPixel(image, x1, y1);
 
-			pixel = pixels[(y * image->w) + x];
+			putPixel(flipped, x2, y2, pixel);
 
-			pixels = (int *)flipped->pixels;
-
-			if (white == TRUE)
-			{
-				SDL_GetRGB(pixel, game.screen->format, &r, &g, &b);
-
-				pixels[(y * flipped->w) + rx] = (r == TRANS_R && g == TRANS_G && b == TRANS_B) ? pixel : color;
-			}
-
-			else
-			{
-				pixels[(y * flipped->w) + rx] = pixel;
-			}
+			x2++;
 		}
+
+		x2 = 0;
+
+		y2++;
 	}
 
 	if (SDL_MUSTLOCK(image))
@@ -170,25 +164,9 @@ void drawFlippedImage(SDL_Surface *image, int destX, int destY, int white, int a
 		SDL_SetColorKey(flipped, SDL_RLEACCEL|SDL_SRCCOLORKEY, image->format->colorkey);
 	}
 
-	if (alpha != 255 && white == FALSE)
-	{
-		SDL_SetAlpha(flipped, SDL_SRCALPHA|SDL_RLEACCEL, alpha);
-	}
-
-	Set the blitting rectangle to the size of the src image
-
-	dest.x = game.offsetX + destX;
-	dest.y = game.offsetY + destY;
-	dest.w = flipped->w;
-	dest.h = flipped->h;
-
-	Blit the entire image onto the screen at coordinates x and y
-
-	SDL_BlitSurface(flipped, NULL, game.screen, &dest);
-
-	SDL_FreeSurface(flipped);
+	return flipped;
 }
-*/
+
 SDL_Surface *flipImage(SDL_Surface *image)
 {
 	int x, y;
@@ -439,7 +417,7 @@ void drawColouredLine(int x1, int y1, int x2, int y2, Uint32 color1, Uint32 colo
 
 		while (x1 != x2)
 		{
-			if (x1 >= clipX && x1 < clipW && y1 >= clipY && y1 < clipH)
+			if (x1 >= clipX && x1 < clipW && y1 - 2 >= clipY && y1 + 2 < clipH)
 			{
 				putPixel(game.screen, x1, y1 - 2, color3);
 				putPixel(game.screen, x1, y1 - 1, color2);
@@ -460,7 +438,7 @@ void drawColouredLine(int x1, int y1, int x2, int y2, Uint32 color1, Uint32 colo
 			x1 += lStep;
 		}
 
-		if (x1 >= clipX && x1 < clipW && y1 >= clipY && y1 < clipH)
+		if (x1 >= clipX && x1 < clipW && y1 - 2 >= clipY && y1 + 2 < clipH)
 		{
 			putPixel(game.screen, x1, y1 - 2, color3);
 			putPixel(game.screen, x1, y1 - 1, color2);
@@ -474,7 +452,7 @@ void drawColouredLine(int x1, int y1, int x2, int y2, Uint32 color1, Uint32 colo
 
 	while (y1 != y2)
 	{
-		if (x1 >= clipX && x1 < clipW && y1 >= clipY && y1 < clipH)
+		if (x1 >= clipX && x1 < clipW && y1 - 2 >= clipY && y1 + 2 < clipH)
 		{
 			putPixel(game.screen, x1, y1 - 2, color3);
 			putPixel(game.screen, x1, y1 - 1, color2);
@@ -495,7 +473,7 @@ void drawColouredLine(int x1, int y1, int x2, int y2, Uint32 color1, Uint32 colo
 		y1 += sStep;
 	}
 
-	if (x1 >= clipX && x1 < clipW && y1 >= clipY && y1 < clipH)
+	if (x1 >= clipX && x1 < clipW && y1 - 2 >= clipY && y1 + 2 < clipH)
 	{
 		putPixel(game.screen, x1, y1 - 2, color3);
 		putPixel(game.screen, x1, y1 - 1, color2);
@@ -720,12 +698,12 @@ SDL_Surface *addBorder(SDL_Surface *surface, int r, int g, int b, int br, int bg
 	SDL_Rect rect;
 	SDL_Surface *newSurface;
 
-	newSurface = createSurface(surface->w + 10, surface->h + 10);
+	newSurface = createSurface(surface->w + BORDER_PADDING * 2, surface->h + BORDER_PADDING * 2);
 
 	SDL_FillRect(newSurface, NULL, SDL_MapRGB(game.screen->format, br, bg, bb));
 
-	rect.x = 5;
-	rect.y = 5;
+	rect.x = BORDER_PADDING;
+	rect.y = BORDER_PADDING;
 	rect.w = surface->w;
 	rect.h = surface->h;
 
@@ -1073,3 +1051,29 @@ static void putPixel(SDL_Surface *surface, int x, int y, Uint32 pixel)
 		break;
 	}
 }
+
+void setScreenshotDir(char *name)
+{
+	STRNCPY(screenshotPath, name, sizeof(screenshotPath));
+
+	printf("Set screenshot directory to %s\n", screenshotPath);
+}
+
+void takeScreenshot()
+{
+	char filename[MAX_PATH_LENGTH];
+
+	if (strlen(screenshotPath) != 0)
+	{
+		snprintf(filename, sizeof(filename), "%s/edgar%06d.bmp", screenshotPath, frame);
+
+		frame++;
+
+		SDL_SaveBMP(game.screen, filename);
+	}
+}
+
+void takeSingleScreenshot(char *name)
+{
+	SDL_SaveBMP(game.screen, name);
+}
