@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,15 +14,16 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
-#include "system/record.h"
-#include "init.h"
-#include "game.h"
 #include "credits.h"
+#include "game.h"
+#include "graphics/graphics.h"
+#include "init.h"
+#include "system/record.h"
 
 extern Input input, menuInput;
 extern Game game;
@@ -72,7 +73,14 @@ void getInput(int gameType)
 						exit(0);
 					}
 				}
-				
+
+				else if (game.status == IN_TITLE)
+				{
+					pauseGame();
+
+					return;
+				}
+
 				else if (game.status == IN_CREDITS)
 				{
 					if (key == SDLK_ESCAPE || key == SDLK_BACKSPACE || key == control.button[CONTROL_PAUSE] || key == control.button[CONTROL_ATTACK])
@@ -189,7 +197,7 @@ void getInput(int gameType)
 
 				else if (key == SCREENSHOT_KEY && game.gameType != RECORDING)
 				{
-					takeSingleScreenshot();
+					takeSingleScreenshot("edgar.bmp");
 				}
 
 				if (key == SDLK_UP)
@@ -212,7 +220,7 @@ void getInput(int gameType)
 					menuInput.left = TRUE;
 				}
 
-				else if (key == SDLK_RETURN || key == SDLK_KP_ENTER)
+				else if (key == SDLK_RETURN || key  == SDLK_KP_ENTER)
 				{
 					menuInput.attack = TRUE;
 				}
@@ -327,7 +335,7 @@ void getInput(int gameType)
 					menuInput.left = FALSE;
 				}
 
-				else if (key == SDLK_RETURN || key == SDLK_KP_ENTER)
+				else if (key == SDLK_RETURN || key  == SDLK_KP_ENTER)
 				{
 					menuInput.attack = FALSE;
 				}
@@ -374,7 +382,7 @@ void getInput(int gameType)
 				key = event.jbutton.button;
 
 				key = -(key + 1000);
-				
+
 				if (game.status == IN_CREDITS)
 				{
 					if (key == control.button[CONTROL_PAUSE] || key == control.button[CONTROL_ATTACK])
@@ -383,6 +391,13 @@ void getInput(int gameType)
 					}
 				}
 
+				else if (game.status == IN_TITLE)
+				{
+					pauseGame();
+
+					return;
+				}
+
 				else if (key == control.button[CONTROL_PAUSE])
 				{
 					pauseGame();
@@ -862,7 +877,12 @@ char *getKeyValue(int key)
 {
 	char *text;
 
-	if (key < 0)
+	if (key == -1)
+	{
+		text = "?";
+	}
+
+	else if (key < 0)
 	{
 		text = getJoystickButton(key);
 	}
