@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,24 +14,24 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
+#include "dialog.h"
+#include "entity.h"
+#include "event/global_trigger.h"
+#include "event/trigger.h"
 #include "graphics/animation.h"
 #include "graphics/graphics.h"
-#include "player.h"
+#include "hud.h"
+#include "inventory.h"
 #include "item/item.h"
 #include "item/key_items.h"
-#include "hud.h"
-#include "event/trigger.h"
-#include "event/global_trigger.h"
-#include "system/properties.h"
-#include "entity.h"
-#include "dialog.h"
-#include "inventory.h"
+#include "player.h"
 #include "system/error.h"
+#include "system/properties.h"
 
 static Inventory inventory;
 extern Entity *self;
@@ -85,6 +85,7 @@ void freeInventory()
 int addToInventory(Entity *e)
 {
 	int i, found;
+	Entity *temp;
 
 	found = FALSE;
 
@@ -129,6 +130,17 @@ int addToInventory(Entity *e)
 					e->action = &doNothing;
 				}
 
+				if (strcmpignorecase(e->name, "item/safe_combination") == 0)
+				{
+					temp = self;
+
+					self = e;
+
+					self->activate(1);
+
+					self = temp;
+				}
+
 				e->flags &= ~DO_NOT_PERSIST;
 
 				inventory.item[i] = *e;
@@ -137,7 +149,7 @@ int addToInventory(Entity *e)
 
 				inventory.item[i].thinkTime = 0;
 
-				setEntityAnimation(&inventory.item[i], "STAND");
+				setEntityAnimationByID(&inventory.item[i], 0);
 
 				if (inventory.item[i].type == WEAPON)
 				{
@@ -349,7 +361,7 @@ void selectInventoryItem(void)
 	{
 		inventory.selectedIndex = inventory.cursorIndex;
 
-		setInventoryDialogMessage(_("Readied %s"), _(inventory.item[inventory.cursorIndex].objectiveName));
+		setInventoryDialogMessage(_("Selected %s"), _(inventory.item[inventory.cursorIndex].objectiveName));
 	}
 }
 
@@ -402,7 +414,7 @@ void replaceInventoryItem(char *name, Entity *e)
 
 			inventory.item[i].thinkTime = 0;
 
-			setEntityAnimation(&inventory.item[i], "STAND");
+			setEntityAnimationByID(&inventory.item[i], 0);
 
 			return;
 		}
@@ -425,7 +437,9 @@ void replaceInventoryItemWithName(char *name, Entity *e)
 
 			inventory.item[i].thinkTime = 0;
 
-			setEntityAnimation(&inventory.item[i], "STAND");
+			inventory.item[i].alpha = 255;
+
+			setEntityAnimationByID(&inventory.item[i], 0);
 
 			return;
 		}
@@ -499,33 +513,20 @@ int removeInventoryItemByName(char *name)
 	{
 		if (inventory.item[i].inUse == TRUE && strcmpignorecase(inventory.item[i].name, name) == 0)
 		{
-			if (inventory.item[i].flags & STACKABLE)
-			{
-				inventory.item[i].health--;
+			inventory.item[i].inUse = FALSE;
 
-				if (inventory.item[i].health <= 0)
-				{
-					inventory.item[i].inUse = FALSE;
-				}
+			if (strcmpignorecase(playerWeapon.name, inventory.item[i].name) == 0)
+			{
+				e = removePlayerWeapon();
+
+				e->inUse = FALSE;
 			}
 
-			else
+			else if (strcmpignorecase(playerShield.name, inventory.item[i].name) == 0)
 			{
-				inventory.item[i].inUse = FALSE;
+				e = removePlayerShield();
 
-				if (strcmpignorecase(playerWeapon.name, inventory.item[i].name) == 0)
-				{
-					e = removePlayerWeapon();
-
-					e->inUse = FALSE;
-				}
-
-				else if (strcmpignorecase(playerShield.name, inventory.item[i].name) == 0)
-				{
-					e = removePlayerShield();
-
-					e->inUse = FALSE;
-				}
+				e->inUse = FALSE;
 			}
 
 			found = TRUE;
@@ -682,7 +683,7 @@ void loadInventoryItems()
 
 			inventory.item[i].currentAnim = -1;
 
-			setEntityAnimation(&inventory.item[i], "STAND");
+			setEntityAnimationByID(&inventory.item[i], 0);
 
 			if (inventory.item[i].type == WEAPON && strcmpignorecase(inventory.item[i].name, playerWeapon.name) == 0)
 			{
@@ -835,7 +836,7 @@ void clearInventoryDescription()
 
 void drawInventory()
 {
-	int i, x, y;
+	int i, x, y, descriptionY;
 	char description[MAX_MESSAGE_LENGTH];
 	Entity *e;
 
@@ -881,6 +882,8 @@ void drawInventory()
 
 	e = &inventory.item[inventory.cursorIndex];
 
+	descriptionY = inventory.y + inventory.background->h + 10;
+
 	if (inventory.description == NULL)
 	{
 		if (e->inUse == TRUE)
@@ -907,13 +910,18 @@ void drawInventory()
 
 			inventory.description = createDialogBox(NULL, description);
 
-			drawImage(inventory.description, (SCREEN_WIDTH - inventory.description->w) / 2, inventory.y + inventory.background->h + 10, FALSE, 255);
+			drawImage(inventory.description, (SCREEN_WIDTH - inventory.description->w) / 2, descriptionY, FALSE, 255);
 		}
 	}
 
 	else
 	{
-		drawImage(inventory.description, (SCREEN_WIDTH - inventory.description->w) / 2, inventory.y + inventory.background->h + 10, FALSE, 255);
+		drawImage(inventory.description, (SCREEN_WIDTH - inventory.description->w) / 2, descriptionY, FALSE, 255);
+	}
+
+	if (inventory.description != NULL)
+	{
+		descriptionY += inventory.description->h + 10;
 	}
 
 	if (inventory.objectives == NULL)
@@ -934,7 +942,7 @@ void drawInventory()
 
 	drawImage(inventory.cursor, x, y, FALSE, 255);
 
-	drawImage(inventory.objectives, (SCREEN_WIDTH - inventory.objectives->w) / 2, 325, FALSE, 255);
+	drawImage(inventory.objectives, (SCREEN_WIDTH - inventory.objectives->w) / 2, descriptionY, FALSE, 255);
 }
 
 void setInventoryDialogMessage(char *fmt, ...)
@@ -993,7 +1001,7 @@ void scriptAddToInventory(char *name, int quiet)
 
 			inventory.item[i].thinkTime = 0;
 
-			setEntityAnimation(&inventory.item[i], "STAND");
+			setEntityAnimationByID(&inventory.item[i], 0);
 
 			if (quiet == FALSE)
 			{
