@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,27 +14,27 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
-#include "map.h"
-#include "system/resources.h"
-#include "system/random.h"
-#include "graphics/graphics.h"
 #include "audio/audio.h"
-#include "entity.h"
-#include "world/target.h"
-#include "player.h"
 #include "audio/music.h"
-#include "game.h"
-#include "event/trigger.h"
-#include "weather.h"
-#include "system/pak.h"
-#include "geometry.h"
 #include "credits.h"
+#include "entity.h"
+#include "event/trigger.h"
+#include "game.h"
+#include "geometry.h"
+#include "graphics/graphics.h"
+#include "map.h"
+#include "player.h"
 #include "system/error.h"
+#include "system/pak.h"
+#include "system/random.h"
+#include "system/resources.h"
+#include "weather.h"
+#include "world/target.h"
 
 static Map map;
 static SDL_Surface *mapImages[MAX_TILES];
@@ -259,9 +259,9 @@ void loadMap(char *name, int loadEntityResources)
 					showErrorAndExit("Failed to allocate a whole %d bytes for the animated tile count", (int)(sizeof(int *) * map.animTileTotal));
 				}
 			}
-			
+
 			/* A set of animated tiles */
-			
+
 			for (animTileID=0;animTileID<map.animTileTotal;animTileID++)
 			{
 				line = strtok_r(NULL, "\n", &savePtr1);
@@ -278,13 +278,13 @@ void loadMap(char *name, int loadEntityResources)
 				{
 					showErrorAndExit("Failed to allocate a whole %d bytes for the animated tiles", (int)(sizeof(int) * y));
 				}
-				
+
 				token = strtok_r(line, " ", &savePtr2);
 
 				for (x=0;x<y;x++)
 				{
 					map.animTile[animTileID].tile[x] = atoi(token);
-					
+
 					token = strtok_r(NULL, " ", &savePtr2);
 				}
 			}
@@ -376,7 +376,87 @@ void loadMap(char *name, int loadEntityResources)
 
 		line = strtok_r(NULL, "\n", &savePtr1);
 	}
+	/*
+	printf("X %d - %d Y: %d - %d\n", map.minX, map.maxX, map.minY, map.maxY);
 
+	yy = 0;
+
+	if (map.minY != 0 || map.minX != 0)
+	{
+		for (y=map.minY;y<=map.maxY;y++)
+		{
+			xx = 0;
+
+			for (x=map.minX;x<=map.maxX;x++)
+			{
+				map.tile[yy][xx] = map.tile[y][x];
+
+				xx++;
+
+				map.tile[y][x] = 0;
+			}
+
+			yy++;
+		}
+
+
+		map.minX *= TILE_SIZE;
+		map.minY *= TILE_SIZE;
+
+		printf("MAP_NAME %s\nTRANSLATE_ENTITIES %d %d\n", name, map.minX, map.minY);
+
+		entities = getEntities();
+
+		player.x -= map.minX;
+		player.y -= map.minY;
+
+		for (el=entities->next;el!=NULL;el=el->next)
+		{
+			e = el->entity;
+
+			e->x -= map.minX;
+			e->y -= map.minY;
+
+			if (e->startX - map.minX > 0)
+			{
+				e->startX -= map.minX;
+			}
+
+			if (e->startY - map.minY > 0)
+			{
+				e->startY -= map.minY;
+			}
+
+			if (e->endX - map.minX > 0)
+			{
+				e->endX -= map.minX;
+			}
+
+			if (e->endY - map.minY > 0)
+			{
+				e->endY -= map.minY;
+			}
+		}
+
+		targets = getTargets();
+
+		for (x=0;x<MAX_TARGETS;x++)
+		{
+			if (targets[x].active == TRUE)
+			{
+				if (targets[x].x - map.minX > 0)
+				{
+					targets[x].x -= map.minX;
+				}
+
+				if (targets[x].y - map.minY > 0)
+				{
+					targets[x].y -= map.minY;
+				}
+			}
+		}
+	}
+	*/
 	/* Set the maximum scroll position of the map */
 
 	map.maxX = (map.maxX + 1) * TILE_SIZE;
@@ -763,12 +843,12 @@ void drawMap(int depth)
 				exit(0);
 			}
 			*/
-			
+
 			if (game.status == IN_CREDITS)
 			{
 				drawBox(game.screen, x, y, TILE_SIZE, TILE_SIZE, 0, 0, 0);
 			}
-			
+
 			else
 			{
 				switch (depth)
@@ -1056,42 +1136,42 @@ int mapTileAt(int x, int y)
 	return map.tile[y][x];
 }
 
-int getMaxMapX()
+int getMapMaxX()
 {
 	return map.maxX;
 }
 
-int getMaxMapY()
+int getMapMaxY()
 {
 	return map.maxY;
 }
 
-void setMaxMapX(int max)
+void setMapMaxX(int max)
 {
 	map.maxX = max;
 }
 
-void setMaxMapY(int max)
+void setMapMaxY(int max)
 {
 	map.maxY = max;
 }
 
-void setMinMapX(int min)
+void setMapMinX(int min)
 {
 	map.minX = min;
 }
 
-void setMinMapY(int min)
+void setMapMinY(int min)
 {
 	map.minY = min;
 }
 
-int getMinMapX()
+int getMapMinX()
 {
 	return map.minX;
 }
 
-int getMinMapY()
+int getMapMinY()
 {
 	return map.minY;
 }
@@ -1254,6 +1334,19 @@ void setCameraPosition(int x, int y)
 {
 	map.cameraX = x;
 	map.cameraY = y;
+
+	map.startX = map.cameraX;
+	map.startY = map.cameraY;
+}
+
+void setCameraPositionFromScript(char *position)
+{
+	char *x, *y;
+
+	x = strtok(position, " ");
+	y = strtok(NULL, " ");
+
+	setCameraPosition(atoi(x), atoi(y));
 }
 
 void limitCamera(int minX, int minY, int maxX, int maxY)
@@ -1370,16 +1463,6 @@ int getDistanceFromCamera(int x, int y)
 	return getDistance(map.cameraX + SCREEN_WIDTH / 2, map.cameraY + SCREEN_HEIGHT / 2, x, y);
 }
 
-int outOfBounds(Entity *e)
-{
-	if (e->x < map.startX || e->x > map.startX + SCREEN_WIDTH || e->y < map.startY || e->y > map.startY + SCREEN_HEIGHT)
-	{
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
 void setDarkMap(int dark)
 {
 	map.darkMap = dark;
