@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,27 +14,29 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
-#include "main_menu.h"
-#include "options_menu.h"
-#include "sound_menu.h"
-#include "io_menu.h"
+#include "about_menu.h"
+#include "cheat_menu.h"
 #include "control_menu.h"
+#include "inventory_menu.h"
+#include "io_menu.h"
+#include "main_menu.h"
+#include "medals_menu.h"
+#include "ok_menu.h"
+#include "options_menu.h"
+#include "script_menu.h"
+#include "sound_menu.h"
 #include "stats_menu.h"
 #include "yes_no_menu.h"
-#include "inventory_menu.h"
-#include "ok_menu.h"
-#include "cheat_menu.h"
-#include "about_menu.h"
 
 extern Game game;
 
 void doMenu()
-{
+{	
 	game.menu->action();
 }
 
@@ -66,4 +68,8 @@ void freeMenus()
 	freeOKMenu();
 	
 	freeAboutMenu();
+	
+	freeMedalsMenu();
+	
+	freeScriptMenu();
 }
