@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,32 +14,33 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "headers.h"
 
-#include "graphics/animation.h"
-#include "system/properties.h"
-#include "map.h"
-#include "medal.h"
-#include "geometry.h"
-#include "inventory.h"
+#include "audio/audio.h"
+#include "audio/music.h"
 #include "collisions.h"
 #include "custom_actions.h"
-#include "player.h"
+#include "enemy/rock.h"
 #include "entity.h"
-#include "game.h"
 #include "event/script.h"
-#include "hud.h"
-#include "audio/music.h"
-#include "audio/audio.h"
-#include "graphics/gib.h"
-#include "projectile.h"
+#include "game.h"
+#include "geometry.h"
+#include "graphics/animation.h"
 #include "graphics/decoration.h"
-#include "system/error.h"
-#include "system/random.h"
+#include "graphics/gib.h"
+#include "hud.h"
+#include "inventory.h"
 #include "item/item.h"
+#include "map.h"
+#include "medal.h"
+#include "player.h"
+#include "projectile.h"
+#include "system/error.h"
+#include "system/properties.h"
+#include "system/random.h"
 
 extern Entity player, playerShield, playerWeapon;
 extern Entity *self;
@@ -80,6 +81,10 @@ static void shieldAttack(void);
 static void shieldAttackMove(void);
 static void shieldTouch(Entity *);
 static void shieldSideAttackInit(void);
+static void starWait(void);
+static void applyPetrification(void);
+static void applyAsh(void);
+static void becomeAsh(void);
 
 Entity *loadPlayer(int x, int y, char *name)
 {
@@ -104,7 +109,7 @@ Entity *loadPlayer(int x, int y, char *name)
 			player.maxHealth = player.health = 5;
 		#endif
 
-		setEntityAnimation(&player, "STAND");
+		setEntityAnimationByID(&player, 0);
 
 		player.draw = &drawLoopingAnimationToMap;
 
@@ -128,7 +133,7 @@ Entity *loadPlayer(int x, int y, char *name)
 
 		loadInventoryItems();
 
-		setEntityAnimation(&player, "STAND");
+		setEntityAnimationByID(&player, 0);
 
 		setPlayerLocation(x, y);
 
@@ -145,6 +150,8 @@ Entity *loadPlayer(int x, int y, char *name)
 
 	clearCustomActions(&player);
 
+	player.thinkTime = 0;
+
 	player.alpha = 255;
 
 	player.element = NO_ELEMENT;
@@ -162,9 +169,15 @@ Entity *loadPlayer(int x, int y, char *name)
 	player.touch = &touch;
 
 	centerMapOnEntity(&player);
-	
+
 	player.creditsAction = creditsMove;
 
+	player.maxThinkTime = 0;
+
+	player.standingOn = NULL;
+
+	setCheckpoint(player.x, player.y);
+
 	return &player;
 }
 
@@ -195,6 +208,7 @@ void setPlayerShieldName(char *name)
 void doPlayer()
 {
 	int i, j;
+	int left, right, up, down, attack, block;
 	long travelled;
 
 	travelled = game.distanceTravelled;
@@ -228,7 +242,12 @@ void doPlayer()
 				default:
 					self->dirY += GRAVITY_SPEED * self->weight;
 
-					if (self->dirY >= MAX_AIR_SPEED)
+					if (self->weight < 0 && self->dirY < -2)
+					{
+						self->dirY = -2;
+					}
+
+					else if (self->dirY >= MAX_AIR_SPEED)
 					{
 						self->dirY = MAX_AIR_SPEED;
 					}
@@ -251,7 +270,7 @@ void doPlayer()
 
 		if (self->action == NULL)
 		{
-			self->flags &= ~(HELPLESS|INVULNERABLE|FLASH|ATTRACTED);
+			self->flags &= ~(HELPLESS|INVULNERABLE|FLASH|ATTRACTED|CONFUSED);
 
 			for (i=0;i<MAX_CUSTOM_ACTIONS;i++)
 			{
@@ -263,13 +282,62 @@ void doPlayer()
 
 			if (!(self->flags & HELPLESS))
 			{
-				/* Don't reset the speed if being pulled towards target */
+				/* Don't reset the speed if being pulled towards target or on ice */
 
-				if (!(self->flags & ATTRACTED))
+				if (!(self->flags & ATTRACTED) && !(self->flags & FRICTIONLESS))
 				{
 					self->dirX = 0;
 				}
 
+				/* If confused, then swap around all the controls */
+
+				left = right = 0;
+				up = down = 0;
+				attack = block = 0;
+
+				if (self->flags & CONFUSED)
+				{
+					if (input.left == 1)
+					{
+						right = 1;
+					}
+
+					else if (input.right == 1)
+					{
+						left = 1;
+					}
+
+					if (input.up == 1)
+					{
+						down = 1;
+					}
+
+					else if (input.down == 1)
+					{
+						up = 1;
+					}
+
+					if (input.attack == 1)
+					{
+						block = 1;
+					}
+
+					if (input.block == 1)
+					{
+						attack = 1;
+					}
+				}
+
+				else
+				{
+					left = input.left;
+					right = input.right;
+					up = input.up;
+					down = input.down;
+					attack = input.attack;
+					block = input.block;
+				}
+
 				if (!(self->flags & ON_GROUND) || (self->standingOn != NULL && self->standingOn->dirY != 0))
 				{
 					self->flags &= ~GRABBING;
@@ -297,7 +365,7 @@ void doPlayer()
 					self->flags |= ON_GROUND;
 				}
 
-				if (input.left == 1)
+				if (left == 1)
 				{
 					if (self->flags & BLOCKING)
 					{
@@ -308,20 +376,56 @@ void doPlayer()
 					{
 						if ((playerWeapon.flags & ATTACKING) && !(self->flags & ON_GROUND))
 						{
-							self->dirX -= self->speed;
+							if (self->flags & FRICTIONLESS)
+							{
+								self->dirX -= self->speed * 0.01;
+
+								if (self->dirX < -self->speed)
+								{
+									self->dirX = -self->speed;
+								}
+							}
+
+							else
+							{
+								self->dirX -= self->speed;
+							}
 						}
 
 						else if (!(playerWeapon.flags & ATTACKING))
 						{
-							self->dirX -= self->speed;
+							if (self->flags & FRICTIONLESS)
+							{
+								self->dirX -= self->speed * 0.01;
+
+								if (self->dirX < -self->speed)
+								{
+									self->dirX = -self->speed;
+								}
+							}
+
+							else
+							{
+								self->dirX -= self->speed;
+							}
 
 							/* Only pull the target */
 
-							if ((self->flags & GRABBING) && self->target != NULL && self->target->x > self->x)
+							if ((self->flags & GRABBING) && self->target != NULL)
 							{
-								self->target->dirX = -self->speed;
+								if (self->target->x > self->x)
+								{
+									self->target->dirX = self->dirX;
 
-								self->target->frameSpeed = -1;
+									self->target->frameSpeed = -1;
+								}
+
+								else
+								{
+									self->target->dirX = 0;
+
+									self->target->frameSpeed = 0;
+								}
 							}
 
 							else
@@ -336,7 +440,7 @@ void doPlayer()
 					}
 				}
 
-				else if (input.right == 1)
+				else if (right == 1)
 				{
 					if (self->flags & BLOCKING)
 					{
@@ -347,20 +451,56 @@ void doPlayer()
 					{
 						if ((playerWeapon.flags & ATTACKING) && !(self->flags & ON_GROUND))
 						{
-							self->dirX += self->speed;
+							if (self->flags & FRICTIONLESS)
+							{
+								self->dirX += self->speed * 0.01;
+
+								if (self->dirX > self->speed)
+								{
+									self->dirX = self->speed;
+								}
+							}
+
+							else
+							{
+								self->dirX += self->speed;
+							}
 						}
 
 						else if (!(playerWeapon.flags & ATTACKING))
 						{
-							self->dirX += self->speed;
+							if (self->flags & FRICTIONLESS)
+							{
+								self->dirX += self->speed * 0.01;
+
+								if (self->dirX > self->speed)
+								{
+									self->dirX = self->speed;
+								}
+							}
+
+							else
+							{
+								self->dirX += self->speed;
+							}
 
 							/* Only pull the target */
 
-							if ((self->flags & GRABBING) && self->target != NULL && self->target->x < self->x)
+							if ((self->flags & GRABBING) && self->target != NULL)
 							{
-								self->target->dirX = self->speed;
+								if (self->target->x < self->x)
+								{
+									self->target->dirX = self->dirX;
 
-								self->target->frameSpeed = 1;
+									self->target->frameSpeed = 1;
+								}
+
+								else
+								{
+									self->target->dirX = 0;
+
+									self->target->frameSpeed = 0;
+								}
 							}
 
 							else
@@ -375,7 +515,7 @@ void doPlayer()
 					}
 				}
 
-				else if (input.left == 0 && input.right == 0 && !(self->flags & BLOCKING) && !(playerWeapon.flags & ATTACKING))
+				else if (left == 0 && right == 0 && !(self->flags & BLOCKING) && !(playerWeapon.flags & ATTACKING))
 				{
 					setEntityAnimation(self, "STAND");
 					setEntityAnimation(&playerShield, "STAND");
@@ -389,7 +529,7 @@ void doPlayer()
 					}
 				}
 
-				if (input.up == 1)
+				if (up == 1)
 				{
 					if (self->element == WATER && self->environment == WATER)
 					{
@@ -416,10 +556,11 @@ void doPlayer()
 						}
 
 						input.up = 0;
+						input.down = 0;
 					}
 				}
 
-				if (input.down == 1)
+				if (down == 1)
 				{
 					if (self->environment == WATER || (self->flags & FLY))
 					{
@@ -442,11 +583,12 @@ void doPlayer()
 							}
 
 							input.down = 0;
+							input.up = 0;
 						}
 					}
 				}
 
-				if (input.attack == 1 && !(self->flags & GRABBED))
+				if (attack == 1 && !(self->flags & GRABBED))
 				{
 					if (!(self->flags & BLOCKING))
 					{
@@ -465,14 +607,22 @@ void doPlayer()
 							setEntityAnimation(self, "STAND");
 							setEntityAnimation(&playerShield, "STAND");
 							setEntityAnimation(&playerWeapon, "STAND");
-							
+
 							playerShield.action = &shieldAttack;
-							
+
 							playerShield.action();
 						}
 					}
 
-					input.attack = 0;
+					if (self->flags & CONFUSED)
+					{
+						input.block = 0;
+					}
+
+					else
+					{
+						input.attack = 0;
+					}
 				}
 
 				if (input.interact == 1)
@@ -501,7 +651,7 @@ void doPlayer()
 					}
 				}
 
-				if (input.block == 1 && (self->flags & ON_GROUND) && playerShield.inUse == TRUE && !(playerWeapon.flags & ATTACKING) && !(self->flags & GRABBED))
+				if (block == 1 && (self->flags & ON_GROUND) && playerShield.inUse == TRUE && !(playerWeapon.flags & ATTACKING) && !(self->flags & GRABBED))
 				{
 					self->flags |= BLOCKING;
 
@@ -512,7 +662,7 @@ void doPlayer()
 					playerShield.mental++;
 				}
 
-				else if ((input.block == 0 && (self->flags & BLOCKING)))
+				else if ((block == 0 && (self->flags & BLOCKING)))
 				{
 					self->flags &= ~BLOCKING;
 
@@ -537,7 +687,7 @@ void doPlayer()
 					input.next = input.previous = 0;
 				}
 
-				if (input.jump == 1 && !(self->flags & BLOCKING))
+				if (input.jump == 1 && !(self->flags & (BLOCKING|GRABBED)))
 				{
 					if (self->element == WATER && self->environment == WATER)
 					{
@@ -559,7 +709,10 @@ void doPlayer()
 							}
 						}
 
-						self->dirY = -JUMP_HEIGHT;
+						if (!(player.flags & GROUNDED))
+						{
+							self->dirY = -JUMP_HEIGHT;
+						}
 					}
 
 					if (!(self->element == WATER && self->environment == WATER))
@@ -603,6 +756,11 @@ void doPlayer()
 			{
 				checkToMap(self);
 
+				if (self->flags & ON_GROUND)
+				{
+					self->flags &= ~FRICTIONLESS;
+				}
+
 				if (self->environment == AIR && i == WATER && self->dirY < 0)
 				{
 					self->dirY = -JUMP_HEIGHT;
@@ -693,7 +851,10 @@ void playerWaitForDialog()
 
 	player.flags |= INVULNERABLE;
 
-	player.action = &dialogWait;
+	if (player.maxThinkTime != 1)
+	{
+		player.action = &dialogWait;
+	}
 }
 
 void playerResumeNormal()
@@ -702,7 +863,10 @@ void playerResumeNormal()
 	{
 		player.target = NULL;
 
-		player.action = NULL;
+		if (player.maxThinkTime != 1)
+		{
+			player.action = NULL;
+		}
 
 		player.flags &= ~INVULNERABLE;
 	}
@@ -753,7 +917,7 @@ static void dialogWait()
 
 		self->flags |= ON_GROUND;
 	}
-	
+
 	if (self->flags & ON_GROUND)
 	{
 		self->dirX = 0;
@@ -860,6 +1024,7 @@ void drawPlayer()
 			}
 		}
 	}
+
 	self = &player;
 
 	if (self->health <= 0 && self->thinkTime == 0)
@@ -881,6 +1046,16 @@ void setPlayerShield(int val)
 
 	if (playerWeapon.flags & ATTACKING)
 	{
+		if (game.status == IN_INVENTORY)
+		{
+			setInventoryDialogMessage(_("Cannot equip items whilst attacking"));
+		}
+
+		else
+		{
+			setInfoBoxMessage(120, 255, 255, 255, _("Cannot equip items whilst attacking"));
+		}
+
 		return;
 	}
 
@@ -918,6 +1093,16 @@ void setPlayerWeapon(int val)
 
 	if (playerWeapon.flags & ATTACKING)
 	{
+		if (game.status == IN_INVENTORY)
+		{
+			setInventoryDialogMessage(_("Cannot equip items whilst attacking"));
+		}
+
+		else
+		{
+			setInfoBoxMessage(120, 255, 255, 255, _("Cannot equip items whilst attacking"));
+		}
+
 		return;
 	}
 
@@ -1063,13 +1248,16 @@ static void takeDamage(Entity *other, int damage)
 			{
 				player.dirX = other->dirX < 0 ? -2 : 2;
 
-				checkToMap(&player);
+				other->x = other->dirX > 0 ? player.x - other->w : player.x + player.w;
 
 				setCustomAction(&player, &helpless, 2, 0, 0);
 
 				if (playerShield.thinkTime <= 0)
 				{
-					playSoundToMap("sound/edgar/block.ogg", EDGAR_CHANNEL, player.x, player.y, 0);
+					if (other->element != DRAGON_FIRE)
+					{
+						playSoundToMap("sound/edgar/block.ogg", EDGAR_CHANNEL, player.x, player.y, 0);
+					}
 
 					playerShield.thinkTime = 5;
 				}
@@ -1087,7 +1275,7 @@ static void takeDamage(Entity *other, int damage)
 
 					self = other;
 
-					self->reactToBlock(temp);
+					self->reactToBlock(&playerShield);
 
 					self = temp;
 
@@ -1112,53 +1300,74 @@ static void takeDamage(Entity *other, int damage)
 			if (other->dirX != 0)
 			{
 				player.dirX = other->dirX < 0 ? -2 : 2;
+
+				other->x = other->dirX > 0 ? player.x - other->w : player.x + player.w;
 			}
 
 			else
 			{
 				player.dirX = player.x < other->x ? -6 : 6;
+
+				other->x = other->x < player.x ? player.x - other->w : player.x + player.w;
 			}
 
-			checkToMap(&player);
-
 			setCustomAction(&player, &helpless, 2, 0, 0);
 
+			if (other->reactToBlock == NULL)
+			{
+				other->dirX = 0;
+			}
+
+			else
+			{
+				temp = self;
+
+				self = other;
+
+				self->reactToBlock(&playerShield);
+
+				self = temp;
+			}
+
 			if (playerShield.thinkTime <= 0)
 			{
 				playSoundToMap("sound/edgar/block.ogg", EDGAR_CHANNEL, player.x, player.y, 0);
 
 				playerShield.thinkTime = 5;
-				
+
 				if (strcmpignorecase(other->objectiveName, "SORCEROR_DISINTEGRATION_SPELL") == 0)
 				{
 					if (strcmpignorecase(playerShield.objectiveName, "Disintegration Shield") == 0)
 					{
 						playerShield.health++;
-						
+
 						if (playerShield.health >= 4)
 						{
 							setInfoBoxMessage(360, 255, 255, 255, _("Press Attack whilst Blocking to use your shield..."));
-							
+
 							playerShield.health = 4;
 						}
-						
+
+						else
+						{
+							setInfoBoxMessage(180, 255, 255, 255, _("Your shield is increasing in power..."));
+						}
+
 						shieldHealth = playerShield.health;
-						
+
 						STRNCPY(oldShieldName, playerShield.name, sizeof(oldShieldName));
-						
+
 						snprintf(shieldName, MAX_VALUE_LENGTH, "weapon/disintegration_shield_%d", shieldHealth);
-						
+
 						loadProperties(shieldName, &playerShield);
-						
+
 						replaceInventoryItemWithName(oldShieldName, &playerShield);
-						
+
 						playerShield.thinkTime = 5;
-						
+
 						playerShield.health = shieldHealth;
-						
+
 						alignAnimations(&playerShield);
-						
-						setInfoBoxMessage(180, 255, 255, 255, _("Your shield is increasing in power..."));
 					}
 				}
 			}
@@ -1170,26 +1379,6 @@ static void takeDamage(Entity *other, int damage)
 				addMedal("blocked");
 			}
 
-			other->x = other->x < player.x ? player.x - other->w - 4 : player.x + player.w + 4;
-
-			if (other->reactToBlock == NULL)
-			{
-				other->dirX = other->dirX < 0 ? 2 : -2;
-
-				checkToMap(other);
-			}
-
-			else
-			{
-				temp = self;
-
-				self = other;
-
-				self->reactToBlock(temp);
-
-				self = temp;
-			}
-
 			return;
 		}
 	}
@@ -1378,6 +1567,8 @@ static void fallout()
 	{
 		centerMapOnEntity(NULL);
 
+		player.maxThinkTime = 1;
+
 		player.thinkTime = 120;
 
 		player.dirX = 0;
@@ -1424,7 +1615,7 @@ static void resetPause()
 	switch (player.environment)
 	{
 		case LAVA:
-			minHealth = 99999;
+			minHealth = game.lavaIsFatal == FALSE ? 2 : 99999;
 		break;
 
 		case SLIME:
@@ -1436,7 +1627,8 @@ static void resetPause()
 		break;
 	}
 
-	if ((player.health <= minHealth && getInventoryItemByObjectiveName("Amulet of Resurrection") == NULL) || player.environment == LAVA)
+	if ((player.health <= minHealth && getInventoryItemByObjectiveName("Amulet of Resurrection") == NULL)
+		|| (player.environment == LAVA && game.lavaIsFatal == TRUE))
 	{
 		player.health = 0;
 
@@ -1478,6 +1670,8 @@ static void resetPlayer()
 		cameraSnapToTargetEntity();
 	}
 
+	player.maxThinkTime = 0;
+
 	player.action = NULL;
 
 	player.touch = &touch;
@@ -1519,6 +1713,11 @@ void increasePlayerMaxHealth()
 	{
 		addMedal("10_hp");
 	}
+
+	else if (player.health == 20)
+	{
+		addMedal("20_hp");
+	}
 }
 
 void syncWeaponShieldToPlayer()
@@ -1547,8 +1746,6 @@ static void playerDie()
 
 	player.health = 0;
 
-	/*player.flags &= ~NO_DRAW;*/
-
 	player.flags |= HELPLESS;
 
 	playerWeapon.flags &= ~(ATTACKING|FLY);
@@ -1831,6 +2028,76 @@ static void applySlime()
 	}
 }
 
+void setPlayerConfused(int thinkTime)
+{
+	int i;
+	Entity *e;
+
+	if (player.health <= 0)
+	{
+		return;
+	}
+
+	/* Change back to Edgar */
+
+	if (player.element == WATER)
+	{
+		becomeEdgar();
+	}
+
+	if (!(player.flags & CONFUSED))
+	{
+		for (i=0;i<2;i++)
+		{
+			e = getFreeEntity();
+
+			if (e == NULL)
+			{
+				showErrorAndExit("No free slots to add Edgar's Star");
+			}
+
+			loadProperties("boss/armour_boss_star", e);
+
+			e->x = player.x;
+			e->y = player.y;
+
+			e->action = &starWait;
+
+			e->draw = &drawLoopingAnimationToMap;
+
+			e->thinkTime = thinkTime;
+
+			e->head = &player;
+
+			setEntityAnimation(e, "STAND");
+
+			e->currentFrame = (i == 0 ? 0 : 6);
+
+			e->x = player.x + player.w / 2 - e->w / 2;
+
+			e->y = player.y - e->h;
+		}
+	}
+
+	setCustomAction(&player, &confused, thinkTime, 0, 0);
+}
+
+static void starWait()
+{
+	self->thinkTime--;
+
+	if (self->thinkTime <= 0 || self->head->health <= 0)
+	{
+		self->inUse = FALSE;
+	}
+
+	self->x = self->head->x + self->head->w / 2 - self->w / 2;
+
+	self->y = self->head->y - self->h - 8;
+
+	setInfoBoxMessage(0, 255, 255, 255, _("Your controls have been reversed!"));
+}
+
 static void swingSword()
 {
 	setEntityAnimation(self, "ATTACK_1");
@@ -1871,7 +2138,7 @@ static void fireArrow()
 
 	if (arrow != NULL)
 	{
-		e = addProjectile(arrow->name, &playerWeapon, playerWeapon.x + (player.face == RIGHT ? 0 : player.w), player.y + 15, player.face == RIGHT ? arrow->speed : -arrow->speed, 0);
+		e = addProjectile(arrow->name, &playerWeapon, playerWeapon.x + (player.face == RIGHT ? 0 : player.w), player.y + player.offsetY, player.face == RIGHT ? arrow->speed : -arrow->speed, 0);
 
 		if (e->face == LEFT)
 		{
@@ -1920,31 +2187,31 @@ static void fireArrow()
 static void shieldAttack()
 {
 	Entity *shield = removePlayerShield();
-	
+
 	if (shield == NULL)
 	{
 		return;
 	}
-	
+
 	shield->target = getEntityByObjectiveName("SORCEROR");
-	
+
 	if (shield->target == NULL)
 	{
 		showErrorAndExit("Shield could not find Sorceror");
 	}
-	
+
 	shield->thinkTime = 60;
-	
+
 	shield->action = &shieldAttackInit;
-	
+
 	shield->touch = &shieldTouch;
-	
+
 	shield->mental = 0;
-	
+
 	shield->flags |= FLY;
-	
+
 	shield->layer = FOREGROUND_LAYER;
-	
+
 	if (player.face == LEFT)
 	{
 		shield->x = player.x + player.w - shield->w - shield->offsetX;
@@ -1956,45 +2223,45 @@ static void shieldAttack()
 	}
 
 	shield->y = player.y + shield->offsetY;
-	
+
 	setEntityAnimation(shield, "SHIELD_ATTACK");
-	
+
 	setCustomAction(shield, &spriteTrail, 3600, 0, 0);
 }
 
 static void shieldAttackInit()
 {
 	float x, y, radians;
-	
+
 	if (self->target->startX == 2)
 	{
 		self->thinkTime--;
 	}
-	
+
 	if (self->thinkTime <= 0)
 	{
 		self->x = player.x + player.w / 2 - self->w / 2;
 		self->y = player.y + player.h / 2 - self->h / 2;
-		
+
 		self->targetX = self->target->x + self->target->w / 2 - self->w / 2;
 		self->targetY = self->target->y + self->target->h / 2 - self->h / 2;
-		
+
 		calculatePath(self->x, self->y, self->targetX, self->targetY, &self->dirX, &self->dirY);
-		
+
 		self->dirX *= self->speed * 2;
 		self->dirY *= self->speed * 2;
-		
+
 		self->action = &shieldAttackMove;
-		
+
 		self->thinkTime = 300;
-		
+
 		self->mental = 0;
-		
+
 		self->health = 30;
-		
+
 		self->maxThinkTime = 30;
 	}
-	
+
 	else
 	{
 		x = 0;
@@ -2024,9 +2291,9 @@ static void shieldAttackMove()
 {
 	self->x += self->dirX;
 	self->y += self->dirY;
-	
+
 	self->thinkTime--;
-	
+
 	if (self->thinkTime <= 0 && self->mental == 0)
 	{
 		self->fallout();
@@ -2036,40 +2303,40 @@ static void shieldAttackMove()
 static void shieldAttackVanish()
 {
 	Entity *temp;
-	
+
 	self->x += self->dirX;
 	self->y += self->dirY;
-	
+
 	self->thinkTime--;
-	
+
 	if (self->thinkTime <= 0)
 	{
 		self->flags |= NO_DRAW;
-		
+
 		self->maxThinkTime -= 5;
-		
+
 		self->thinkTime = self->maxThinkTime;
-		
+
 		self->action = &shieldSideAttackInit;
-		
+
 		self->health--;
-		
+
 		if (self->health <= 0)
 		{
 			temp = self;
-			
+
 			self = self->target;
-			
+
 			clearCustomAction(self, &helpless);
-			
+
 			self->die();
-			
+
 			self = temp;
-			
+
 			clearCustomAction(self, &spriteTrail);
-			
+
 			setEntityAnimation(self, "STAND");
-			
+
 			self->fallout();
 		}
 	}
@@ -2078,51 +2345,51 @@ static void shieldAttackVanish()
 static void shieldSideAttackInit()
 {
 	self->thinkTime--;
-	
+
 	if (self->thinkTime <= 0)
 	{
 		self->x = self->target->x + self->target->w / 2 - self->w / 2;
 		self->y = self->target->y + self->target->h / 2 - self->h / 2;
-		
+
 		switch (self->mental)
 		{
 			case 0:
 				self->x -= 32;
 			break;
-			
+
 			case 1:
 				self->x += 32;
 			break;
-			
+
 			case 2:
 				self->y -= 32;
 			break;
-			
+
 			case 3:
 				self->y += 32;
 			break;
-			
+
 			case 4:
 				self->x -= 32;
 				self->y -= 32;
 			break;
-			
+
 			case 5:
 				self->x += 32;
 				self->y -= 32;
 			break;
-			
+
 			case 6:
 				self->x += 32;
 				self->y += 32;
 			break;
-			
+
 			default:
 				self->x -= 32;
 				self->y += 32;
 			break;
 		}
-		
+
 		self->targetX = self->target->x + self->target->w / 2 - self->w / 2;
 		self->targetY = self->target->y + self->target->h / 2 - self->h / 2;
 
@@ -2132,15 +2399,15 @@ static void shieldSideAttackInit()
 		self->dirY *= self->speed;
 
 		self->action = &shieldAttackMove;
-		
+
 		self->touch = &shieldTouch;
 
 		self->thinkTime = 300;
-		
+
 		self->flags &= ~NO_DRAW;
-		
+
 		self->mental++;
-		
+
 		if (self->mental >= 8)
 		{
 			self->mental = 0;
@@ -2154,17 +2421,17 @@ static void shieldTouch(Entity *other)
 	{
 		other->dirX = 0;
 		other->dirY = 0;
-		
+
 		setCustomAction(other, &helpless, 300, 0, 0);
-		
+
 		self->action = &shieldAttackVanish;
-		
+
 		self->touch = NULL;
-		
+
 		self->thinkTime = 10;
-		
+
 		playSoundToMap("sound/edgar/shield.ogg", BOSS_CHANNEL, player.x, player.y, 0);
-		
+
 		other->health = 0;
 	}
 }
@@ -2362,6 +2629,8 @@ Entity *removePlayerWeapon()
 
 		e = addPermanentItem(playerWeapon.name, self->x, self->y);
 
+		e->mental = playerWeapon.mental;
+
 		playerWeapon.inUse = FALSE;
 	}
 
@@ -2382,7 +2651,7 @@ Entity *removePlayerShield()
 		removeInventoryItemByObjectiveName(playerShield.objectiveName);
 
 		e = addPermanentItem(playerShield.name, self->x, self->y);
-		
+
 		e->health = playerShield.health;
 
 		playerShield.inUse = FALSE;
@@ -2593,6 +2862,269 @@ static void applyWebbing()
 	checkToMap(self);
 }
 
+void setPlayerPetrified()
+{
+	Entity *e = getFreeEntity();
+
+	if (e == NULL)
+	{
+		showErrorAndExit("No free slots to add Petrified Player");
+	}
+
+	loadProperties("edgar/edgar_petrify", e);
+
+	e->x = player.x;
+	e->y = player.y;
+
+	e->startX = e->x;
+
+	e->action = &applyPetrification;
+
+	e->face = player.face;
+
+	e->draw = &drawLoopingAnimationToMap;
+	e->touch = &entityTouch;
+	e->takeDamage = NULL;
+
+	e->type = ENEMY;
+
+	e->head = self;
+
+	e->maxThinkTime = 10;
+
+	e->thinkTime = e->maxThinkTime;
+
+	e->health = 4;
+
+	setEntityAnimationByID(e, e->health);
+
+	setPlayerLocked(TRUE);
+
+	player.flags &= ~NO_DRAW;
+
+	player.element = SLIME;
+}
+
+static void applyPetrification()
+{
+	Entity *e;
+
+	if (self->thinkTime <= 0)
+	{
+		playSoundToMap("sound/item/crack.ogg", -1, self->x, self->y, 0);
+
+		self->health--;
+
+		self->thinkTime = self->maxThinkTime;
+
+		if (self->health < 0)
+		{
+			e = addSmallRock(self->x, self->y, "common/small_rock");
+
+			e->x += (self->w - e->w) / 2;
+			e->y -= e->h;
+
+			e->dirX = -3;
+			e->dirY = -8;
+
+			e->layer = FOREGROUND_LAYER;
+
+			e = addSmallRock(self->x, self->y, "common/small_rock");
+
+			e->x += (self->w - e->w) / 2;
+			e->y -= e->h;
+
+			e->dirX = 3;
+			e->dirY = -8;
+
+			e->layer = FOREGROUND_LAYER;
+
+			self->inUse = FALSE;
+
+			setPlayerLocked(FALSE);
+
+			playSoundToMap("sound/common/crumble.ogg", -1, self->x, self->y, 0);
+
+			player.element = NO_ELEMENT;
+		}
+
+		else
+		{
+			setEntityAnimationByID(self, self->health);
+		}
+	}
+
+	if (player.health > 0 && (input.up == 1 || input.down == 1 || input.right == 1 ||
+		 input.left == 1 || input.previous == 1 || input.next == 1 || input.jump == 1 ||
+		input.activate == 1 || input.attack == 1 || input.interact == 1 || input.block == 1))
+	{
+		player.x = self->startX + 1 * (prand() % 2 == 0 ? 1 : -1);
+		self->x = player.x;
+
+		playSoundToMap("sound/boss/gargoyle/petrify_shake.ogg", EDGAR_CHANNEL, self->x, self->y, 0);
+
+		self->thinkTime--;
+
+		input.up = 0;
+		input.down = 0;
+		input.right = 0;
+		input.left = 0;
+		input.previous = 0;
+		input.next = 0;
+		input.jump = 0;
+		input.activate = 0;
+		input.attack = 0;
+		input.interact = 0;
+		input.block = 0;
+
+		e = addSmallRock(self->x, self->y, "common/small_rock");
+
+		e->x += self->w / 2 - e->w / 2;
+		e->y += self->h / 2 - e->h / 2;
+
+		e->dirX = (2 + prand() % 6) * (prand() % 2 == 0 ? -1 : 1);
+		e->dirY = -8;
+
+		e->thinkTime = 60 + (prand() % 120);
+
+		e->layer = FOREGROUND_LAYER;
+	}
+
+	if (player.health > 0)
+	{
+		setInfoBoxMessage(0, 255, 255, 255, _("Press buttons to break the petrification!"));
+	}
+
+	else
+	{
+		player.flags |= NO_DRAW;
+
+		e = addSmallRock(self->x, self->y, "common/small_rock");
+
+		e->x += (self->w - e->w) / 2;
+		e->y -= e->h;
+
+		e->dirX = -3;
+		e->dirY = -8;
+
+		e->layer = FOREGROUND_LAYER;
+
+		e = addSmallRock(self->x, self->y, "common/small_rock");
+
+		e->x += (self->w - e->w) / 2;
+		e->y -= e->h;
+
+		e->dirX = 3;
+		e->dirY = -8;
+
+		e->layer = FOREGROUND_LAYER;
+
+		e = addSmallRock(self->x, self->y, "common/small_rock");
+
+		e->x += (self->w - e->w) / 2;
+		e->y -= e->h;
+
+		e->dirX = -3;
+		e->dirY = -4;
+
+		e->layer = FOREGROUND_LAYER;
+
+		e = addSmallRock(self->x, self->y, "common/small_rock");
+
+		e->x += (self->w - e->w) / 2;
+		e->y -= e->h;
+
+		e->dirX = 3;
+		e->dirY = -4;
+
+		e->layer = FOREGROUND_LAYER;
+
+		self->inUse = FALSE;
+
+		playSoundToMap("sound/common/crumble.ogg", -1, self->x, self->y, 0);
+	}
+
+	self->y = player.y;
+}
+
+void setPlayerAsh()
+{
+	Entity *e = getFreeEntity();
+
+	if (e == NULL)
+	{
+		showErrorAndExit("No free slots to add an Ashed Player");
+	}
+
+	/* Change back to Edgar */
+
+	if (player.element == WATER)
+	{
+		becomeEdgar();
+	}
+
+	loadProperties("edgar/edgar_ash", e);
+
+	e->x = player.x;
+	e->y = player.y;
+
+	e->face = player.face;
+
+	e->action = &applyAsh;
+
+	e->draw = &drawLoopingAnimationToMap;
+
+	setEntityAnimation(e, "STAND");
+
+	e->mental = 0;
+
+	player.dirX = 0;
+	player.dirY = 0;
+}
+
+static void applyAsh()
+{
+	Entity *e;
+
+	self->x = player.x;
+	self->y = player.y;
+
+	if (player.mental == 0 && self->mental == 0)
+	{
+		self->mental = 1;
+
+		setEntityAnimation(self, "BECOME_ASH");
+
+		self->animationCallback = &becomeAsh;
+	}
+
+	if (self->mental == 2)
+	{
+		self->thinkTime--;
+
+		if (self->thinkTime <= 0)
+		{
+			e = addSmoke(self->x + prand() % self->w, self->y + self->h - prand() % 10, "decoration/dust");
+
+			if (e != NULL)
+			{
+				e->dirY = -(5 + prand() % 20);
+
+				e->dirY /= 10;
+			}
+
+			self->thinkTime = 5 + prand() % 10;
+		}
+	}
+}
+
+static void becomeAsh()
+{
+	setEntityAnimation(self, "ASH_WAIT");
+
+	self->mental = 2;
+}
+
 int isAttacking()
 {
 	return (playerWeapon.flags & ATTACKING) ? TRUE : FALSE;
@@ -2829,24 +3361,24 @@ void scriptAttack()
 static void creditsMove()
 {
 	self->thinkTime++;
-	
+
 	setEntityAnimation(self, "WALK");
 	setEntityAnimation(&playerWeapon, "WALK");
 	setEntityAnimation(&playerShield, "WALK");
-	
+
 	self->dirX = self->speed;
-	
+
 	checkToMap(self);
-	
+
 	if (self->dirX == 0 && self->mental != 0)
 	{
 		self->inUse = FALSE;
 	}
-	
+
 	if (self->thinkTime == 180 && self->mental == 0)
 	{
 		self->thinkTime = 60;
-		
+
 		self->creditsAction = &creditsWait;
 	}
 }
@@ -2856,20 +3388,20 @@ static void creditsWait()
 	setEntityAnimation(self, "STAND");
 	setEntityAnimation(&playerWeapon, "STAND");
 	setEntityAnimation(&playerShield, "STAND");
-	
+
 	self->thinkTime--;
-	
+
 	if (self->thinkTime <= 0)
 	{
 		self->face = self->face == LEFT ? RIGHT : LEFT;
-		
+
 		playerWeapon.face = self->face;
 		playerShield.face = self->face;
-		
+
 		self->mental++;
-		
+
 		self->thinkTime = 60;
-		
+
 		if (self->face == RIGHT)
 		{
 			self->creditsAction = &creditsMove;
