@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2011 Parallel Realities
+Copyright (C) 2009-2012 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -14,30 +14,31 @@ See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
 
 #include "../entity.h"
-#include "../event/trigger.h"
 #include "../event/global_trigger.h"
 #include "../event/map_trigger.h"
 #include "../event/objective.h"
-#include "../world/target.h"
-#include "../map.h"
-#include "../player.h"
-#include "../inventory.h"
-#include "compress.h"
-#include "resources.h"
-#include "../graphics/graphics.h"
-#include "../graphics/font.h"
+#include "../event/script.h"
+#include "../event/trigger.h"
 #include "../game.h"
-#include "load_save.h"
+#include "../graphics/font.h"
+#include "../graphics/graphics.h"
 #include "../hud.h"
 #include "../input.h"
-#include "error.h"
+#include "../inventory.h"
+#include "../map.h"
 #include "../medal.h"
+#include "../player.h"
+#include "../world/target.h"
+#include "compress.h"
+#include "error.h"
+#include "load_save.h"
+#include "resources.h"
 
 static char gameSavePath[MAX_PATH_LENGTH], tempFile[MAX_PATH_LENGTH], saveFileIndex[MAX_PATH_LENGTH], continueFile[MAX_PATH_LENGTH];
 static int temporaryDataExists;
@@ -50,27 +51,14 @@ static void showPatchMessage(char *);
 
 extern Game game;
 
-#ifndef WIN32
+#ifndef _WIN32
 	void setupUserHomeDirectory()
 	{
 		char *userHome;
-		char *name;
 		char dir[MAX_PATH_LENGTH];
 		struct passwd *pass;
 
-		name = getlogin();
-
-		STRNCPY(dir, "", sizeof(dir));
-
-		if (name != NULL)
-		{
-			pass = getpwnam(name);
-		}
-
-		else
-		{
-			pass = getpwuid(geteuid());
-		}
+		pass = getpwuid(geteuid());
 
 		if (pass == NULL)
 		{
@@ -135,10 +123,10 @@ void startOnMap(char *mapName)
 
 	freeGameResources();
 
-	loadMap(mapName, TRUE);
-
 	initGame();
 
+	loadMap(mapName, TRUE);
+
 	cameraSnapToTargetEntity();
 }
 
@@ -148,11 +136,11 @@ void newGame()
 
 	freeGameResources();
 
-	loadMap("map01", TRUE);
-
 	initGame();
 
-	cameraSnapToTargetEntity();
+	loadMap("map04", TRUE);
+
+	runScript("intro_part1");
 }
 
 void tutorial()
@@ -161,11 +149,22 @@ void tutorial()
 
 	freeGameResources();
 
+	initGame();
+
 	loadMap("tutorial", TRUE);
 
+	cameraSnapToTargetEntity();
+}
+
+void titleScreen()
+{
+	removeTemporaryData();
+
+	freeGameResources();
+
 	initGame();
 
-	cameraSnapToTargetEntity();
+	game.status = IN_TITLE;
 }
 
 int loadGame(int slot)
@@ -198,7 +197,7 @@ int loadGame(int slot)
 	buffer = decompressFile(saveFile);
 
 	line = strtok_r((char *)buffer, "\n", &savePtr);
-	
+
 	foundResources = FALSE;
 
 	while (line != NULL)
@@ -296,7 +295,7 @@ int loadGame(int slot)
 		else if (strcmpignorecase(line, mapName) == 0)
 		{
 			foundResources = TRUE;
-			
+
 			loadResources(savePtr);
 		}
 
@@ -345,13 +344,13 @@ int loadGame(int slot)
 
 		return loadGame(slot);
 	}
-	
+
 	/* Fudge to make a game saved in the new Village map still load OK */
-	
+
 	if (foundResources == FALSE)
 	{
 		sscanf(mapName, "%*s %s\n", itemName);
-		
+
 		loadMap(itemName, TRUE);
 	}
 
@@ -424,7 +423,7 @@ static void patchSaveGame(char *saveFile, double version)
 		else if (strcmpignorecase("MAP_NAME", itemName) == 0)
 		{
 			saveMap = TRUE;
-			
+
 			if (strlen(mapName) == 0 || strcmpignorecase(line, mapName) == 0)
 			{
 				sscanf(line, "%*s %s\n", itemName);
@@ -454,7 +453,7 @@ static void patchSaveGame(char *saveFile, double version)
 				/* Load up the patch file */
 
 				saveMap = patchEntities(version, itemName);
-				
+
 				if (saveMap == FALSE)
 				{
 					snprintf(itemName, sizeof(itemName), "%ld_old", game.playTime * SDL_GetTicks());
@@ -592,40 +591,8 @@ void saveGame(int slot)
 
 	else
 	{
-		/* Backup older save
+		/* Backup older save */
 
-		for (i=1;;i++)
-		{
-			snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, slot);
-
-			read = fopen(saveFile, "rb");
-
-			if (read == NULL)
-			{
-				break;
-			}
-
-			else
-			{
-				fclose(read);
-			}
-
-			snprintf(backupFile, sizeof(backupFile), "%ssave%d.%04d", gameSavePath, slot, i);
-
-			read = fopen(backupFile, "rb");
-
-			if (read != NULL)
-			{
-				fclose(read);
-
-				continue;
-			}
-
-			copyFile(saveFile, backupFile);
-
-			break;
-		}
-		*/
 		snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, slot);
 	}
 
@@ -834,6 +801,44 @@ static void updateSaveFileIndex(int slot)
 	fclose(fp);
 }
 
+int getMostRecentSave()
+{
+	char saveFile[MAX_PATH_LENGTH];
+	struct stat fileInfo;
+	int i, modTime, slot;
+	FILE *fp;
+
+	modTime = 0;
+
+	slot = -1;
+
+	for (i=0;i<MAX_SAVE_SLOTS;i++)
+	{
+		snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, i);
+
+		fp = fopen(saveFile, "rb");
+
+		if (fp == NULL)
+		{
+			continue;
+		}
+
+		if (stat(saveFile, &fileInfo) != -1)
+		{
+			if (fileInfo.st_mtime > modTime)
+			{
+				modTime = fileInfo.st_mtime;
+
+				slot = i;
+			}
+		}
+
+		fclose(fp);
+	}
+
+	return slot;
+}
+
 void saveTemporaryData()
 {
 	char *line, itemName[MAX_MESSAGE_LENGTH], *savePtr;
@@ -1334,7 +1339,7 @@ int hasPersistance(char *mapName)
 		if (strcmpignorecase(line, itemName) == 0)
 		{
 			val = TRUE;
-			
+
 			break;
 		}
 
@@ -1388,7 +1393,7 @@ int bossExists(char *bossName)
 		if (strstr(line, bossName) != NULL)
 		{
 			val = TRUE;
-			
+
 			break;
 		}
 
@@ -1522,7 +1527,7 @@ void loadConfig()
 	buffer[length] = '\0';
 
 	fclose(fp);
-	
+
 	savePtr = NULL;
 
 	line = strtok_r((char *)buffer, "\n", &savePtr);
@@ -1671,28 +1676,6 @@ char **getSaveFileIndex()
 	return entries;
 }
 
-int getPrivateKey(char *privateKey)
-{
-	int result;
-	char keyPath[MAX_PATH_LENGTH];
-	FILE *fp;
-
-	snprintf(keyPath, MAX_PATH_LENGTH, "%smedalKey", gameSavePath);
-
-	fp = fopen(keyPath, "rb");
-
-	if (fp == NULL)
-	{
-		return FALSE;
-	}
-
-	result = fscanf(fp, "%s", privateKey);
-
-	fclose(fp);
-
-	return TRUE;
-}
-
 static void showPatchMessage(char *message)
 {
 	int y;
@@ -1743,6 +1726,8 @@ void loadObtainedMedals()
 	unsigned char *buffer;
 	FILE *fp;
 
+	savePtr = NULL;
+
 	snprintf(medalFile, MAX_PATH_LENGTH, "%smedals", gameSavePath);
 
 	fp = fopen(medalFile, "rb");
@@ -1751,20 +1736,20 @@ void loadObtainedMedals()
 	{
 		return;
 	}
-	
+
 	fclose(fp);
 
 	buffer = decompressFile(medalFile);
 
 	line = strtok_r((char *)buffer, "\n", &savePtr);
-	
+
 	while (line != NULL)
 	{
 		setObtainedMedal(line);
-		
+
 		line = strtok_r(NULL, "\n", &savePtr);
 	}
-	
+
 	free(buffer);
 }
 
@@ -1783,11 +1768,11 @@ void saveObtainedMedals()
 	{
 		showErrorAndExit("Could not save Medal data: %s", strerror(errno));
 	}
-	
+
 	medalCount = getMedalCount();
-	
+
 	medal = getMedals();
-	
+
 	for (i=0;i<medalCount;i++)
 	{
 		if (medal[i].obtained == TRUE)
@@ -1795,9 +1780,9 @@ void saveObtainedMedals()
 			fprintf(fp, "%s\n", medal[i].code);
 		}
 	}
-	
+
 	fclose(fp);
-	
+
 	#if DEV == 1
 		copyFile(medalFile, "medaldata");
 	#endif
